package com.mysql.jdbc;

import java.lang.reflect.Constructor;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Locale;
import java.util.Map;
import java.util.StringTokenizer;
import java.util.TreeMap;

/* loaded from: com_mysql_jdbc.jar:com/mysql/jdbc/DatabaseMetaData.class */
public class DatabaseMetaData implements java.sql.DatabaseMetaData {
    private static String mysqlKeywordsThatArentSQL92;
    protected static final int MAX_IDENTIFIER_LENGTH = 64;
    private static final int DEFERRABILITY = 13;
    private static final int DELETE_RULE = 10;
    private static final int FK_NAME = 11;
    private static final int FKCOLUMN_NAME = 7;
    private static final int FKTABLE_CAT = 4;
    private static final int FKTABLE_NAME = 6;
    private static final int FKTABLE_SCHEM = 5;
    private static final int KEY_SEQ = 8;
    private static final int PK_NAME = 12;
    private static final int PKCOLUMN_NAME = 3;
    private static final int PKTABLE_CAT = 0;
    private static final int PKTABLE_NAME = 2;
    private static final int PKTABLE_SCHEM = 1;
    private static final String SUPPORTS_FK = "SUPPORTS_FK";
    private static final int UPDATE_RULE = 9;
    private static final Constructor JDBC_4_DBMD_SHOW_CTOR;
    private static final Constructor JDBC_4_DBMD_IS_CTOR;
    protected ConnectionImpl conn;
    protected String database;
    protected String quotedId;
    static Class class$com$mysql$jdbc$ConnectionImpl;
    static Class class$java$lang$String;
    private static final byte[] TABLE_AS_BYTES = "TABLE".getBytes();
    private static final byte[] VIEW_AS_BYTES = "VIEW".getBytes();

    static String access$000(DatabaseMetaData x0, String x1) {
        return x0.getTableNameWithCase(x1);
    }

    static LocalAndReferencedColumns access$100(DatabaseMetaData x0, String x1) throws SQLException {
        return x0.parseTableStatusIntoLocalAndReferencedColumns(x1);
    }

    static String access$200(DatabaseMetaData x0, String x1) {
        return x0.removeQuotedId(x1);
    }

    static int[] access$300(DatabaseMetaData x0, String x1) {
        return x0.getForeignKeyActions(x1);
    }

    static void access$400(DatabaseMetaData x0, String x1, String x2, String x3, List x4, String x5) throws SQLException {
        x0.getExportKeyResults(x1, x2, x3, x4, x5);
    }

    static void access$500(DatabaseMetaData x0, String x1, String x2, String x3, List x4) throws SQLException {
        x0.getImportKeyResults(x1, x2, x3, x4);
    }

    static void access$600(DatabaseMetaData x0, boolean x1, String x2, ResultSet x3, boolean x4, String x5, Map x6, int x7) throws SQLException {
        x0.convertToJdbcProcedureList(x1, x2, x3, x4, x5, x6, x7);
    }

    static void access$700(DatabaseMetaData x0, String x1, ResultSet x2, boolean x3, String x4, Map x5, int x6, Field[] x7) throws SQLException {
        x0.convertToJdbcFunctionList(x1, x2, x3, x4, x5, x6, x7);
    }

    static byte[] access$800() {
        return TABLE_AS_BYTES;
    }

    static byte[] access$900() {
        return VIEW_AS_BYTES;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    /* loaded from: com_mysql_jdbc.jar:com/mysql/jdbc/DatabaseMetaData$IterateBlock.class */
    public abstract class IterateBlock {
        IteratorWithCleanup iterator;
        private final DatabaseMetaData this$0;

        abstract void forEach(Object obj) throws SQLException;

        IterateBlock(DatabaseMetaData this$0, IteratorWithCleanup i) {
            this.this$0 = this$0;
            this.iterator = i;
        }

        public void doForAll() throws SQLException {
            while (this.iterator.hasNext()) {
                try {
                    forEach(this.iterator.next());
                } finally {
                    this.iterator.close();
                }
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    /* loaded from: com_mysql_jdbc.jar:com/mysql/jdbc/DatabaseMetaData$IteratorWithCleanup.class */
    public abstract class IteratorWithCleanup {
        private final DatabaseMetaData this$0;

        abstract void close() throws SQLException;

        abstract boolean hasNext() throws SQLException;

        abstract Object next() throws SQLException;

        protected IteratorWithCleanup(DatabaseMetaData this$0) {
            this.this$0 = this$0;
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    /* loaded from: com_mysql_jdbc.jar:com/mysql/jdbc/DatabaseMetaData$LocalAndReferencedColumns.class */
    public class LocalAndReferencedColumns {
        String constraintName;
        List localColumnsList;
        String referencedCatalog;
        List referencedColumnsList;
        String referencedTable;
        private final DatabaseMetaData this$0;

        LocalAndReferencedColumns(DatabaseMetaData this$0, List localColumns, List refColumns, String constName, String refCatalog, String refTable) {
            this.this$0 = this$0;
            this.localColumnsList = localColumns;
            this.referencedColumnsList = refColumns;
            this.constraintName = constName;
            this.referencedTable = refTable;
            this.referencedCatalog = refCatalog;
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    /* loaded from: com_mysql_jdbc.jar:com/mysql/jdbc/DatabaseMetaData$ResultSetIterator.class */
    public class ResultSetIterator extends IteratorWithCleanup {
        int colIndex;
        ResultSet resultSet;
        private final DatabaseMetaData this$0;

        ResultSetIterator(DatabaseMetaData this$0, ResultSet rs, int index) {
            super(this$0);
            this.this$0 = this$0;
            this.resultSet = rs;
            this.colIndex = index;
        }

        @Override // com.mysql.jdbc.DatabaseMetaData.IteratorWithCleanup
        void close() throws SQLException {
            this.resultSet.close();
        }

        @Override // com.mysql.jdbc.DatabaseMetaData.IteratorWithCleanup
        boolean hasNext() throws SQLException {
            return this.resultSet.next();
        }

        @Override // com.mysql.jdbc.DatabaseMetaData.IteratorWithCleanup
        Object next() throws SQLException {
            return this.resultSet.getObject(this.colIndex);
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    /* loaded from: com_mysql_jdbc.jar:com/mysql/jdbc/DatabaseMetaData$SingleStringIterator.class */
    public class SingleStringIterator extends IteratorWithCleanup {
        boolean onFirst;
        String value;
        private final DatabaseMetaData this$0;

        SingleStringIterator(DatabaseMetaData this$0, String s) {
            super(this$0);
            this.this$0 = this$0;
            this.onFirst = true;
            this.value = s;
        }

        @Override // com.mysql.jdbc.DatabaseMetaData.IteratorWithCleanup
        void close() throws SQLException {
        }

        @Override // com.mysql.jdbc.DatabaseMetaData.IteratorWithCleanup
        boolean hasNext() throws SQLException {
            return this.onFirst;
        }

        @Override // com.mysql.jdbc.DatabaseMetaData.IteratorWithCleanup
        Object next() throws SQLException {
            this.onFirst = false;
            return this.value;
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    /* loaded from: com_mysql_jdbc.jar:com/mysql/jdbc/DatabaseMetaData$TypeDescriptor.class */
    public class TypeDescriptor {
        int bufferLength;
        int charOctetLength;
        Integer columnSize;
        short dataType;
        Integer decimalDigits;
        String isNullable;
        int nullability;
        int numPrecRadix;
        String typeName;
        private final DatabaseMetaData this$0;

        TypeDescriptor(DatabaseMetaData this$0, String typeInfo, String nullabilityInfo) throws SQLException {
            String mysqlType;
            String fullMysqlType;
            int maxLength;
            int maxLength2;
            this.this$0 = this$0;
            this.numPrecRadix = DatabaseMetaData.DELETE_RULE;
            if (typeInfo == null) {
                throw SQLError.createSQLException("NULL typeinfo not supported.", SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
            }
            if (typeInfo.indexOf("(") != -1) {
                mysqlType = typeInfo.substring(0, typeInfo.indexOf("("));
            } else {
                mysqlType = typeInfo;
            }
            int indexOfUnsignedInMysqlType = StringUtils.indexOfIgnoreCase(mysqlType, "unsigned");
            mysqlType = indexOfUnsignedInMysqlType != -1 ? mysqlType.substring(0, indexOfUnsignedInMysqlType - 1) : mysqlType;
            if (StringUtils.indexOfIgnoreCase(typeInfo, "unsigned") != -1) {
                fullMysqlType = new StringBuffer().append(mysqlType).append(" unsigned").toString();
            } else {
                fullMysqlType = mysqlType;
            }
            fullMysqlType = this$0.conn.getCapitalizeTypeNames() ? fullMysqlType.toUpperCase(Locale.ENGLISH) : fullMysqlType;
            this.dataType = (short) MysqlDefs.mysqlToJavaType(mysqlType);
            this.typeName = fullMysqlType;
            if (StringUtils.startsWithIgnoreCase(typeInfo, "enum")) {
                String temp = typeInfo.substring(typeInfo.indexOf("("), typeInfo.lastIndexOf(")"));
                StringTokenizer tokenizer = new StringTokenizer(temp, ",");
                int i = 0;
                while (true) {
                    maxLength2 = i;
                    if (!tokenizer.hasMoreTokens()) {
                        break;
                    } else {
                        i = Math.max(maxLength2, tokenizer.nextToken().length() - DatabaseMetaData.PKTABLE_NAME);
                    }
                }
                this.columnSize = Constants.integerValueOf(maxLength2);
                this.decimalDigits = null;
            } else if (StringUtils.startsWithIgnoreCase(typeInfo, "set")) {
                String temp2 = typeInfo.substring(typeInfo.indexOf("("), typeInfo.lastIndexOf(")"));
                StringTokenizer tokenizer2 = new StringTokenizer(temp2, ",");
                int i2 = 0;
                while (true) {
                    maxLength = i2;
                    if (!tokenizer2.hasMoreTokens()) {
                        break;
                    }
                    String setMember = tokenizer2.nextToken().trim();
                    if (setMember.startsWith("'") && setMember.endsWith("'")) {
                        i2 = maxLength + (setMember.length() - DatabaseMetaData.PKTABLE_NAME);
                    } else {
                        i2 = maxLength + setMember.length();
                    }
                }
                this.columnSize = Constants.integerValueOf(maxLength);
                this.decimalDigits = null;
            } else if (typeInfo.indexOf(",") != -1) {
                this.columnSize = Integer.valueOf(typeInfo.substring(typeInfo.indexOf("(") + 1, typeInfo.indexOf(",")).trim());
                this.decimalDigits = Integer.valueOf(typeInfo.substring(typeInfo.indexOf(",") + 1, typeInfo.indexOf(")")).trim());
            } else {
                this.columnSize = null;
                this.decimalDigits = null;
                if ((StringUtils.indexOfIgnoreCase(typeInfo, "char") != -1 || StringUtils.indexOfIgnoreCase(typeInfo, "text") != -1 || StringUtils.indexOfIgnoreCase(typeInfo, "blob") != -1 || StringUtils.indexOfIgnoreCase(typeInfo, "binary") != -1 || StringUtils.indexOfIgnoreCase(typeInfo, "bit") != -1) && typeInfo.indexOf("(") != -1) {
                    int endParenIndex = typeInfo.indexOf(")");
                    this.columnSize = Integer.valueOf(typeInfo.substring(typeInfo.indexOf("(") + 1, endParenIndex == -1 ? typeInfo.length() : endParenIndex).trim());
                    if (this$0.conn.getTinyInt1isBit() && this.columnSize.intValue() == 1 && StringUtils.startsWithIgnoreCase(typeInfo, 0, "tinyint")) {
                        if (this$0.conn.getTransformedBitIsBoolean()) {
                            this.dataType = (short) 16;
                            this.typeName = "BOOLEAN";
                        } else {
                            this.dataType = (short) -7;
                            this.typeName = "BIT";
                        }
                    }
                } else if (StringUtils.startsWithIgnoreCaseAndWs(typeInfo, "tinyint")) {
                    if (this$0.conn.getTinyInt1isBit() && typeInfo.indexOf("(1)") != -1) {
                        if (this$0.conn.getTransformedBitIsBoolean()) {
                            this.dataType = (short) 16;
                            this.typeName = "BOOLEAN";
                        } else {
                            this.dataType = (short) -7;
                            this.typeName = "BIT";
                        }
                    } else {
                        this.columnSize = Constants.integerValueOf(DatabaseMetaData.PKCOLUMN_NAME);
                        this.decimalDigits = Constants.integerValueOf(0);
                    }
                } else if (StringUtils.startsWithIgnoreCaseAndWs(typeInfo, "smallint")) {
                    this.columnSize = Constants.integerValueOf(DatabaseMetaData.FKTABLE_SCHEM);
                    this.decimalDigits = Constants.integerValueOf(0);
                } else if (StringUtils.startsWithIgnoreCaseAndWs(typeInfo, "mediumint")) {
                    this.columnSize = Constants.integerValueOf(DatabaseMetaData.FKCOLUMN_NAME);
                    this.decimalDigits = Constants.integerValueOf(0);
                } else if (StringUtils.startsWithIgnoreCaseAndWs(typeInfo, "int")) {
                    this.columnSize = Constants.integerValueOf(DatabaseMetaData.DELETE_RULE);
                    this.decimalDigits = Constants.integerValueOf(0);
                } else if (StringUtils.startsWithIgnoreCaseAndWs(typeInfo, "integer")) {
                    this.columnSize = Constants.integerValueOf(DatabaseMetaData.DELETE_RULE);
                    this.decimalDigits = Constants.integerValueOf(0);
                } else if (StringUtils.startsWithIgnoreCaseAndWs(typeInfo, "bigint")) {
                    this.columnSize = Constants.integerValueOf(19);
                    this.decimalDigits = Constants.integerValueOf(0);
                } else if (StringUtils.startsWithIgnoreCaseAndWs(typeInfo, "int24")) {
                    this.columnSize = Constants.integerValueOf(19);
                    this.decimalDigits = Constants.integerValueOf(0);
                } else if (StringUtils.startsWithIgnoreCaseAndWs(typeInfo, "real")) {
                    this.columnSize = Constants.integerValueOf(DatabaseMetaData.PK_NAME);
                } else if (StringUtils.startsWithIgnoreCaseAndWs(typeInfo, "float")) {
                    this.columnSize = Constants.integerValueOf(DatabaseMetaData.PK_NAME);
                } else if (StringUtils.startsWithIgnoreCaseAndWs(typeInfo, "decimal")) {
                    this.columnSize = Constants.integerValueOf(DatabaseMetaData.PK_NAME);
                } else if (StringUtils.startsWithIgnoreCaseAndWs(typeInfo, "numeric")) {
                    this.columnSize = Constants.integerValueOf(DatabaseMetaData.PK_NAME);
                } else if (StringUtils.startsWithIgnoreCaseAndWs(typeInfo, "double")) {
                    this.columnSize = Constants.integerValueOf(22);
                } else if (StringUtils.startsWithIgnoreCaseAndWs(typeInfo, "char")) {
                    this.columnSize = Constants.integerValueOf(1);
                } else if (StringUtils.startsWithIgnoreCaseAndWs(typeInfo, "varchar")) {
                    this.columnSize = Constants.integerValueOf(255);
                } else if (StringUtils.startsWithIgnoreCaseAndWs(typeInfo, "date")) {
                    this.columnSize = null;
                } else if (StringUtils.startsWithIgnoreCaseAndWs(typeInfo, "time")) {
                    this.columnSize = null;
                } else if (StringUtils.startsWithIgnoreCaseAndWs(typeInfo, "timestamp")) {
                    this.columnSize = null;
                } else if (StringUtils.startsWithIgnoreCaseAndWs(typeInfo, "datetime")) {
                    this.columnSize = null;
                } else if (StringUtils.startsWithIgnoreCaseAndWs(typeInfo, "tinyblob")) {
                    this.columnSize = Constants.integerValueOf(255);
                } else if (StringUtils.startsWithIgnoreCaseAndWs(typeInfo, "blob")) {
                    this.columnSize = Constants.integerValueOf(65535);
                } else if (StringUtils.startsWithIgnoreCaseAndWs(typeInfo, "mediumblob")) {
                    this.columnSize = Constants.integerValueOf(16777215);
                } else if (StringUtils.startsWithIgnoreCaseAndWs(typeInfo, "longblob")) {
                    this.columnSize = Constants.integerValueOf(Integer.MAX_VALUE);
                } else if (StringUtils.startsWithIgnoreCaseAndWs(typeInfo, "tinytext")) {
                    this.columnSize = Constants.integerValueOf(255);
                } else if (StringUtils.startsWithIgnoreCaseAndWs(typeInfo, "text")) {
                    this.columnSize = Constants.integerValueOf(65535);
                } else if (StringUtils.startsWithIgnoreCaseAndWs(typeInfo, "mediumtext")) {
                    this.columnSize = Constants.integerValueOf(16777215);
                } else if (StringUtils.startsWithIgnoreCaseAndWs(typeInfo, "longtext")) {
                    this.columnSize = Constants.integerValueOf(Integer.MAX_VALUE);
                } else if (StringUtils.startsWithIgnoreCaseAndWs(typeInfo, "enum")) {
                    this.columnSize = Constants.integerValueOf(255);
                } else if (StringUtils.startsWithIgnoreCaseAndWs(typeInfo, "set")) {
                    this.columnSize = Constants.integerValueOf(255);
                }
            }
            this.bufferLength = MysqlIO.getMaxBuf();
            this.numPrecRadix = DatabaseMetaData.DELETE_RULE;
            if (nullabilityInfo != null) {
                if (nullabilityInfo.equals("YES")) {
                    this.nullability = 1;
                    this.isNullable = "YES";
                    return;
                } else {
                    this.nullability = 0;
                    this.isNullable = "NO";
                    return;
                }
            }
            this.nullability = 0;
            this.isNullable = "NO";
        }
    }

    static {
        Class<?> cls;
        Class<?> cls2;
        Class<?> cls3;
        Class<?> cls4;
        if (Util.isJdbc4()) {
            try {
                Class<?> cls5 = Class.forName("com.mysql.jdbc.JDBC4DatabaseMetaData");
                Class<?>[] clsArr = new Class[PKTABLE_NAME];
                if (class$com$mysql$jdbc$ConnectionImpl == null) {
                    cls = class$("com.mysql.jdbc.ConnectionImpl");
                    class$com$mysql$jdbc$ConnectionImpl = cls;
                } else {
                    cls = class$com$mysql$jdbc$ConnectionImpl;
                }
                clsArr[0] = cls;
                if (class$java$lang$String == null) {
                    cls2 = class$("java.lang.String");
                    class$java$lang$String = cls2;
                } else {
                    cls2 = class$java$lang$String;
                }
                clsArr[1] = cls2;
                JDBC_4_DBMD_SHOW_CTOR = cls5.getConstructor(clsArr);
                Class<?> cls6 = Class.forName("com.mysql.jdbc.JDBC4DatabaseMetaDataUsingInfoSchema");
                Class<?>[] clsArr2 = new Class[PKTABLE_NAME];
                if (class$com$mysql$jdbc$ConnectionImpl == null) {
                    cls3 = class$("com.mysql.jdbc.ConnectionImpl");
                    class$com$mysql$jdbc$ConnectionImpl = cls3;
                } else {
                    cls3 = class$com$mysql$jdbc$ConnectionImpl;
                }
                clsArr2[0] = cls3;
                if (class$java$lang$String == null) {
                    cls4 = class$("java.lang.String");
                    class$java$lang$String = cls4;
                } else {
                    cls4 = class$java$lang$String;
                }
                clsArr2[1] = cls4;
                JDBC_4_DBMD_IS_CTOR = cls6.getConstructor(clsArr2);
            } catch (ClassNotFoundException e) {
                throw new RuntimeException(e);
            } catch (NoSuchMethodException e2) {
                throw new RuntimeException(e2);
            } catch (SecurityException e3) {
                throw new RuntimeException(e3);
            }
        } else {
            JDBC_4_DBMD_IS_CTOR = null;
            JDBC_4_DBMD_SHOW_CTOR = null;
        }
        String[] allMySQLKeywords = {"ACCESSIBLE", "ADD", "ALL", "ALTER", "ANALYZE", "AND", "AS", "ASC", "ASENSITIVE", "BEFORE", "BETWEEN", "BIGINT", "BINARY", "BLOB", "BOTH", "BY", "CALL", "CASCADE", "CASE", "CHANGE", "CHAR", "CHARACTER", "CHECK", "COLLATE", "COLUMN", "CONDITION", "CONNECTION", "CONSTRAINT", "CONTINUE", "CONVERT", "CREATE", "CROSS", "CURRENT_DATE", "CURRENT_TIME", "CURRENT_TIMESTAMP", "CURRENT_USER", "CURSOR", "DATABASE", "DATABASES", "DAY_HOUR", "DAY_MICROSECOND", "DAY_MINUTE", "DAY_SECOND", "DEC", "DECIMAL", "DECLARE", "DEFAULT", "DELAYED", "DELETE", "DESC", "DESCRIBE", "DETERMINISTIC", "DISTINCT", "DISTINCTROW", "DIV", "DOUBLE", "DROP", "DUAL", "EACH", "ELSE", "ELSEIF", "ENCLOSED", "ESCAPED", "EXISTS", "EXIT", "EXPLAIN", "FALSE", "FETCH", "FLOAT", "FLOAT4", "FLOAT8", "FOR", "FORCE", "FOREIGN", "FROM", "FULLTEXT", "GRANT", "GROUP", "HAVING", "HIGH_PRIORITY", "HOUR_MICROSECOND", "HOUR_MINUTE", "HOUR_SECOND", "IF", "IGNORE", "IN", "INDEX", "INFILE", "INNER", "INOUT", "INSENSITIVE", "INSERT", "INT", "INT1", "INT2", "INT3", "INT4", "INT8", "INTEGER", "INTERVAL", "INTO", "IS", "ITERATE", "JOIN", "KEY", "KEYS", "KILL", "LEADING", "LEAVE", "LEFT", "LIKE", "LIMIT", "LINEAR", "LINES", "LOAD", "LOCALTIME", "LOCALTIMESTAMP", "LOCK", "LONG", "LONGBLOB", "LONGTEXT", "LOOP", "LOW_PRIORITY", "MATCH", "MEDIUMBLOB", "MEDIUMINT", "MEDIUMTEXT", "MIDDLEINT", "MINUTE_MICROSECOND", "MINUTE_SECOND", "MOD", "MODIFIES", "NATURAL", "NOT", "NO_WRITE_TO_BINLOG", "NULL", "NUMERIC", "ON", "OPTIMIZE", "OPTION", "OPTIONALLY", "OR", "ORDER", "OUT", "OUTER", "OUTFILE", "PRECISION", "PRIMARY", "PROCEDURE", "PURGE", "RANGE", "READ", "READS", "READ_ONLY", "READ_WRITE", "REAL", "REFERENCES", "REGEXP", "RELEASE", "RENAME", "REPEAT", "REPLACE", "REQUIRE", "RESTRICT", "RETURN", "REVOKE", "RIGHT", "RLIKE", "SCHEMA", "SCHEMAS", "SECOND_MICROSECOND", "SELECT", "SENSITIVE", "SEPARATOR", "SET", "SHOW", "SMALLINT", "SPATIAL", "SPECIFIC", "SQL", "SQLEXCEPTION", "SQLSTATE", "SQLWARNING", "SQL_BIG_RESULT", "SQL_CALC_FOUND_ROWS", "SQL_SMALL_RESULT", "SSL", "STARTING", "STRAIGHT_JOIN", "TABLE", "TERMINATED", "THEN", "TINYBLOB", "TINYINT", "TINYTEXT", "TO", "TRAILING", "TRIGGER", "TRUE", "UNDO", "UNION", "UNIQUE", "UNLOCK", "UNSIGNED", "UPDATE", "USAGE", "USE", "USING", "UTC_DATE", "UTC_TIME", "UTC_TIMESTAMP", "VALUES", "VARBINARY", "VARCHAR", "VARCHARACTER", "VARYING", "WHEN", "WHERE", "WHILE", "WITH", "WRITE", "X509", "XOR", "YEAR_MONTH", "ZEROFILL"};
        String[] sql92Keywords = {"ABSOLUTE", "EXEC", "OVERLAPS", "ACTION", "EXECUTE", "PAD", "ADA", "EXISTS", "PARTIAL", "ADD", "EXTERNAL", "PASCAL", "ALL", "EXTRACT", "POSITION", "ALLOCATE", "FALSE", "PRECISION", "ALTER", "FETCH", "PREPARE", "AND", "FIRST", "PRESERVE", "ANY", "FLOAT", "PRIMARY", "ARE", "FOR", "PRIOR", "AS", "FOREIGN", "PRIVILEGES", "ASC", "FORTRAN", "PROCEDURE", "ASSERTION", "FOUND", "PUBLIC", "AT", "FROM", "READ", "AUTHORIZATION", "FULL", "REAL", "AVG", "GET", "REFERENCES", "BEGIN", "GLOBAL", "RELATIVE", "BETWEEN", "GO", "RESTRICT", "BIT", "GOTO", "REVOKE", "BIT_LENGTH", "GRANT", "RIGHT", "BOTH", "GROUP", "ROLLBACK", "BY", "HAVING", "ROWS", "CASCADE", "HOUR", "SCHEMA", "CASCADED", "IDENTITY", "SCROLL", "CASE", "IMMEDIATE", "SECOND", "CAST", "IN", "SECTION", "CATALOG", "INCLUDE", "SELECT", "CHAR", "INDEX", "SESSION", "CHAR_LENGTH", "INDICATOR", "SESSION_USER", "CHARACTER", "INITIALLY", "SET", "CHARACTER_LENGTH", "INNER", "SIZE", "CHECK", "INPUT", "SMALLINT", "CLOSE", "INSENSITIVE", "SOME", "COALESCE", "INSERT", "SPACE", "COLLATE", "INT", "SQL", "COLLATION", "INTEGER", "SQLCA", "COLUMN", "INTERSECT", "SQLCODE", "COMMIT", "INTERVAL", "SQLERROR", "CONNECT", "INTO", "SQLSTATE", "CONNECTION", "IS", "SQLWARNING", "CONSTRAINT", "ISOLATION", "SUBSTRING", "CONSTRAINTS", "JOIN", "SUM", "CONTINUE", "KEY", "SYSTEM_USER", "CONVERT", "LANGUAGE", "TABLE", "CORRESPONDING", "LAST", "TEMPORARY", "COUNT", "LEADING", "THEN", "CREATE", "LEFT", "TIME", "CROSS", "LEVEL", "TIMESTAMP", "CURRENT", "LIKE", "TIMEZONE_HOUR", "CURRENT_DATE", "LOCAL", "TIMEZONE_MINUTE", "CURRENT_TIME", "LOWER", "TO", "CURRENT_TIMESTAMP", "MATCH", "TRAILING", "CURRENT_USER", "MAX", "TRANSACTION", "CURSOR", "MIN", "TRANSLATE", "DATE", "MINUTE", "TRANSLATION", "DAY", "MODULE", "TRIM", "DEALLOCATE", "MONTH", "TRUE", "DEC", "NAMES", "UNION", "DECIMAL", "NATIONAL", "UNIQUE", "DECLARE", "NATURAL", "UNKNOWN", "DEFAULT", "NCHAR", "UPDATE", "DEFERRABLE", "NEXT", "UPPER", "DEFERRED", "NO", "USAGE", "DELETE", "NONE", "USER", "DESC", "NOT", "USING", "DESCRIBE", "NULL", "VALUE", "DESCRIPTOR", "NULLIF", "VALUES", "DIAGNOSTICS", "NUMERIC", "VARCHAR", "DISCONNECT", "OCTET_LENGTH", "VARYING", "DISTINCT", "OF", "VIEW", "DOMAIN", "ON", "WHEN", "DOUBLE", "ONLY", "WHENEVER", "DROP", "OPEN", "WHERE", "ELSE", "OPTION", "WITH", "END", "OR", "WORK", "END-EXEC", "ORDER", "WRITE", "ESCAPE", "OUTER", "YEAR", "EXCEPT", "OUTPUT", "ZONE", "EXCEPTION"};
        TreeMap mySQLKeywordMap = new TreeMap();
        for (String str : allMySQLKeywords) {
            mySQLKeywordMap.put(str, null);
        }
        HashMap sql92KeywordMap = new HashMap(sql92Keywords.length);
        for (String str2 : sql92Keywords) {
            sql92KeywordMap.put(str2, null);
        }
        Iterator it = sql92KeywordMap.keySet().iterator();
        while (it.hasNext()) {
            mySQLKeywordMap.remove(it.next());
        }
        StringBuffer keywordBuf = new StringBuffer();
        Iterator it2 = mySQLKeywordMap.keySet().iterator();
        if (it2.hasNext()) {
            keywordBuf.append(it2.next().toString());
        }
        while (it2.hasNext()) {
            keywordBuf.append(",");
            keywordBuf.append(it2.next().toString());
        }
        mysqlKeywordsThatArentSQL92 = keywordBuf.toString();
    }

    static Class class$(String x0) {
        try {
            return Class.forName(x0);
        } catch (ClassNotFoundException x1) {
            throw new NoClassDefFoundError(x1.getMessage());
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public static DatabaseMetaData getInstance(ConnectionImpl connToSet, String databaseToSet) throws SQLException {
        if (Util.isJdbc4()) {
            return (connToSet != null && connToSet.getUseInformationSchema() && connToSet.versionMeetsMinimum(FKTABLE_SCHEM, 0, FKCOLUMN_NAME)) ? (DatabaseMetaData) Util.handleNewInstance(JDBC_4_DBMD_IS_CTOR, new Object[]{connToSet, databaseToSet}) : (DatabaseMetaData) Util.handleNewInstance(JDBC_4_DBMD_SHOW_CTOR, new Object[]{connToSet, databaseToSet});
        }
        if (connToSet != null && connToSet.getUseInformationSchema() && connToSet.versionMeetsMinimum(FKTABLE_SCHEM, 0, FKCOLUMN_NAME)) {
            return new DatabaseMetaDataUsingInfoSchema(connToSet, databaseToSet);
        }
        return new DatabaseMetaData(connToSet, databaseToSet);
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public DatabaseMetaData(ConnectionImpl connToSet, String databaseToSet) {
        this.database = null;
        this.quotedId = null;
        this.conn = connToSet;
        this.database = databaseToSet;
        try {
            this.quotedId = this.conn.supportsQuotedIdentifiers() ? getIdentifierQuoteString() : "";
        } catch (SQLException sqlEx) {
            AssertionFailedException.shouldNotHappen(sqlEx);
        }
    }

    @Override // java.sql.DatabaseMetaData
    public boolean allProceduresAreCallable() throws SQLException {
        return false;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean allTablesAreSelectable() throws SQLException {
        return false;
    }

    private ResultSet buildResultSet(Field[] fields, ArrayList rows) throws SQLException {
        return buildResultSet(fields, rows, this.conn);
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static ResultSet buildResultSet(Field[] fields, ArrayList rows, ConnectionImpl c) throws SQLException {
        int fieldsLength = fields.length;
        for (int i = 0; i < fieldsLength; i++) {
            fields[i].setConnection(c);
            fields[i].setUseOldNameMetadata(true);
        }
        return ResultSetImpl.getInstance(c.getCatalog(), fields, new RowDataStatic(rows), c, null, false);
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r0v23, types: [byte[]] */
    /* JADX WARN: Type inference failed for: r16v1 */
    public void convertToJdbcFunctionList(String str, ResultSet resultSet, boolean z, String str2, Map map, int i, Field[] fieldArr) throws SQLException {
        byte[][] bArr;
        while (resultSet.next()) {
            boolean z2 = true;
            if (z) {
                z2 = false;
                String string = resultSet.getString(1);
                if (str2 == null && string == null) {
                    z2 = true;
                } else if (str2 != null && str2.equals(string)) {
                    z2 = true;
                }
            }
            if (z2) {
                String string2 = resultSet.getString(i);
                if (fieldArr != null && fieldArr.length == KEY_SEQ) {
                    byte[][] bArr2 = new byte[KEY_SEQ];
                    bArr2[0] = str == null ? null : s2b(str);
                    bArr2[1] = null;
                    bArr2[PKTABLE_NAME] = s2b(string2);
                    bArr2[PKCOLUMN_NAME] = null;
                    bArr2[FKTABLE_CAT] = null;
                    bArr2[FKTABLE_SCHEM] = null;
                    bArr2[FKTABLE_NAME] = s2b(resultSet.getString("comment"));
                    bArr2[FKCOLUMN_NAME] = s2b(Integer.toString(PKTABLE_NAME));
                    bArr = bArr2;
                } else {
                    ?? r16 = new byte[FKTABLE_NAME];
                    r16[0] = str == null ? null : s2b(str);
                    r16[1] = 0;
                    r16[PKTABLE_NAME] = s2b(string2);
                    r16[PKCOLUMN_NAME] = s2b(resultSet.getString("comment"));
                    r16[FKTABLE_CAT] = s2b(Integer.toString(getJDBC4FunctionNoTableConstant()));
                    r16[FKTABLE_SCHEM] = s2b(string2);
                    bArr = r16;
                }
                map.put(string2, new ByteArrayRow(bArr));
            }
        }
    }

    protected int getJDBC4FunctionNoTableConstant() {
        return 0;
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* JADX WARN: Type inference failed for: r0v8, types: [byte[], byte[][]] */
    public void convertToJdbcProcedureList(boolean fromSelect, String catalog, ResultSet proceduresRs, boolean needsClientFiltering, String db, Map procedureRowsOrderedByName, int nameIndex) throws SQLException {
        while (proceduresRs.next()) {
            boolean shouldAdd = true;
            if (needsClientFiltering) {
                shouldAdd = false;
                String procDb = proceduresRs.getString(1);
                if (db == null && procDb == null) {
                    shouldAdd = true;
                } else if (db != null && db.equals(procDb)) {
                    shouldAdd = true;
                }
            }
            if (shouldAdd) {
                String procedureName = proceduresRs.getString(nameIndex);
                ?? r0 = new byte[KEY_SEQ];
                r0[0] = catalog == null ? null : s2b(catalog);
                r0[1] = 0;
                r0[PKTABLE_NAME] = s2b(procedureName);
                r0[PKCOLUMN_NAME] = 0;
                r0[FKTABLE_CAT] = 0;
                r0[FKTABLE_SCHEM] = 0;
                r0[FKTABLE_NAME] = 0;
                boolean isFunction = fromSelect ? "FUNCTION".equalsIgnoreCase(proceduresRs.getString("type")) : false;
                r0[FKCOLUMN_NAME] = s2b(isFunction ? Integer.toString(PKTABLE_NAME) : Integer.toString(0));
                procedureRowsOrderedByName.put(procedureName, new ByteArrayRow(r0));
            }
        }
    }

    /* JADX WARN: Multi-variable type inference failed */
    private ResultSetRow convertTypeDescriptorToProcedureRow(byte[] procNameAsBytes, String paramName, boolean isOutParam, boolean isInParam, boolean isReturnParam, TypeDescriptor typeDesc, boolean forGetFunctionColumns, int ordinal) throws SQLException {
        byte[][] bArr = forGetFunctionColumns ? new byte[17] : new byte[14];
        bArr[0] = 0;
        bArr[1] = 0;
        bArr[PKTABLE_NAME] = procNameAsBytes;
        bArr[PKCOLUMN_NAME] = s2b(paramName);
        if (isInParam && isOutParam) {
            bArr[FKTABLE_CAT] = s2b(String.valueOf(PKTABLE_NAME));
        } else if (isInParam) {
            bArr[FKTABLE_CAT] = s2b(String.valueOf(1));
        } else if (isOutParam) {
            bArr[FKTABLE_CAT] = s2b(String.valueOf(FKTABLE_CAT));
        } else if (isReturnParam) {
            bArr[FKTABLE_CAT] = s2b(String.valueOf(FKTABLE_SCHEM));
        } else {
            bArr[FKTABLE_CAT] = s2b(String.valueOf(0));
        }
        bArr[FKTABLE_SCHEM] = s2b(Short.toString(typeDesc.dataType));
        bArr[FKTABLE_NAME] = s2b(typeDesc.typeName);
        bArr[FKCOLUMN_NAME] = typeDesc.columnSize == null ? null : s2b(typeDesc.columnSize.toString());
        bArr[KEY_SEQ] = s2b(Integer.toString(typeDesc.bufferLength));
        bArr[UPDATE_RULE] = typeDesc.decimalDigits == null ? null : s2b(typeDesc.decimalDigits.toString());
        bArr[DELETE_RULE] = s2b(Integer.toString(typeDesc.numPrecRadix));
        switch (typeDesc.nullability) {
            case 0:
                bArr[FK_NAME] = s2b(String.valueOf(0));
                break;
            case 1:
                bArr[FK_NAME] = s2b(String.valueOf(1));
                break;
            case PKTABLE_NAME /* 2 */:
                bArr[FK_NAME] = s2b(String.valueOf(PKTABLE_NAME));
                break;
            default:
                throw SQLError.createSQLException("Internal error while parsing callable statement metadata (unknown nullability value fount)", SQLError.SQL_STATE_GENERAL_ERROR);
        }
        bArr[PK_NAME] = 0;
        if (forGetFunctionColumns) {
            bArr[DEFERRABILITY] = 0;
            bArr[14] = s2b(String.valueOf(ordinal));
            bArr[15] = Constants.EMPTY_BYTE_ARRAY;
            bArr[16] = s2b(paramName);
        }
        return new ByteArrayRow(bArr);
    }

    @Override // java.sql.DatabaseMetaData
    public boolean dataDefinitionCausesTransactionCommit() throws SQLException {
        return true;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean dataDefinitionIgnoredInTransactions() throws SQLException {
        return false;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean deletesAreDetected(int type) throws SQLException {
        return false;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean doesMaxRowSizeIncludeBlobs() throws SQLException {
        return true;
    }

    /* JADX WARN: Type inference failed for: r0v1, types: [byte[], byte[][]] */
    public List extractForeignKeyForTable(ArrayList rows, ResultSet rs, String catalog) throws SQLException {
        int afterFk;
        int indexOfRef;
        int endPos;
        ?? r0 = new byte[PKCOLUMN_NAME];
        r0[0] = rs.getBytes(1);
        r0[1] = s2b(SUPPORTS_FK);
        String createTableString = rs.getString(PKTABLE_NAME);
        StringTokenizer lineTokenizer = new StringTokenizer(createTableString, "\n");
        StringBuffer commentBuf = new StringBuffer("comment; ");
        boolean firstTime = true;
        String quoteChar = getIdentifierQuoteString();
        if (quoteChar == null) {
            quoteChar = "`";
        }
        while (lineTokenizer.hasMoreTokens()) {
            String line = lineTokenizer.nextToken().trim();
            String constraintName = null;
            if (StringUtils.startsWithIgnoreCase(line, "CONSTRAINT")) {
                boolean usingBackTicks = true;
                int beginPos = line.indexOf(quoteChar);
                if (beginPos == -1) {
                    beginPos = line.indexOf("\"");
                    usingBackTicks = false;
                }
                if (beginPos != -1) {
                    if (usingBackTicks) {
                        endPos = line.indexOf(quoteChar, beginPos + 1);
                    } else {
                        endPos = line.indexOf("\"", beginPos + 1);
                    }
                    if (endPos != -1) {
                        constraintName = line.substring(beginPos + 1, endPos);
                        line = line.substring(endPos + 1, line.length()).trim();
                    }
                }
            }
            if (line.startsWith("FOREIGN KEY")) {
                if (line.endsWith(",")) {
                    line = line.substring(0, line.length() - 1);
                }
                char quote = this.quotedId.charAt(0);
                int indexOfFK = line.indexOf("FOREIGN KEY");
                String localColumnName = null;
                String referencedCatalogName = new StringBuffer().append(this.quotedId).append(catalog).append(this.quotedId).toString();
                String referencedTableName = null;
                String referencedColumnName = null;
                if (indexOfFK != -1 && (indexOfRef = StringUtils.indexOfIgnoreCaseRespectQuotes((afterFk = indexOfFK + "FOREIGN KEY".length()), line, "REFERENCES", quote, true)) != -1) {
                    int indexOfParenOpen = line.indexOf(40, afterFk);
                    int indexOfParenClose = StringUtils.indexOfIgnoreCaseRespectQuotes(indexOfParenOpen, line, ")", quote, true);
                    if (indexOfParenOpen == -1 || indexOfParenClose == -1) {
                    }
                    localColumnName = line.substring(indexOfParenOpen + 1, indexOfParenClose);
                    int afterRef = indexOfRef + "REFERENCES".length();
                    int referencedColumnBegin = StringUtils.indexOfIgnoreCaseRespectQuotes(afterRef, line, "(", quote, true);
                    if (referencedColumnBegin != -1) {
                        referencedTableName = line.substring(afterRef, referencedColumnBegin);
                        int referencedColumnEnd = StringUtils.indexOfIgnoreCaseRespectQuotes(referencedColumnBegin + 1, line, ")", quote, true);
                        if (referencedColumnEnd != -1) {
                            referencedColumnName = line.substring(referencedColumnBegin + 1, referencedColumnEnd);
                        }
                        int indexOfCatalogSep = StringUtils.indexOfIgnoreCaseRespectQuotes(0, referencedTableName, ".", quote, true);
                        if (indexOfCatalogSep != -1) {
                            referencedCatalogName = referencedTableName.substring(0, indexOfCatalogSep);
                            referencedTableName = referencedTableName.substring(indexOfCatalogSep + 1);
                        }
                    }
                }
                if (!firstTime) {
                    commentBuf.append("; ");
                } else {
                    firstTime = false;
                }
                if (constraintName != null) {
                    commentBuf.append(constraintName);
                } else {
                    commentBuf.append("not_available");
                }
                commentBuf.append("(");
                commentBuf.append(localColumnName);
                commentBuf.append(") REFER ");
                commentBuf.append(referencedCatalogName);
                commentBuf.append("/");
                commentBuf.append(referencedTableName);
                commentBuf.append("(");
                commentBuf.append(referencedColumnName);
                commentBuf.append(")");
                int lastParenIndex = line.lastIndexOf(")");
                if (lastParenIndex != line.length() - 1) {
                    String cascadeOptions = line.substring(lastParenIndex + 1);
                    commentBuf.append(" ");
                    commentBuf.append(cascadeOptions);
                }
            }
        }
        r0[PKTABLE_NAME] = s2b(commentBuf.toString());
        rows.add(new ByteArrayRow(r0));
        return rows;
    }

    /* JADX WARN: Code restructure failed: missing block: B:34:0x0175, code lost:
    
        if (r13 == null) goto L48;
     */
    /* JADX WARN: Code restructure failed: missing block: B:35:0x0178, code lost:
    
        r13.close();
     */
    /* JADX WARN: Code restructure failed: missing block: B:37:0x0184, code lost:
    
        if (r0 == null) goto L51;
     */
    /* JADX WARN: Code restructure failed: missing block: B:38:0x0187, code lost:
    
        r0.close();
     */
    /* JADX WARN: Code restructure failed: missing block: B:41:0x0170, code lost:
    
        throw r24;
     */
    /* JADX WARN: Code restructure failed: missing block: B:67:0x005c, code lost:
    
        if (r13 == null) goto L18;
     */
    /* JADX WARN: Code restructure failed: missing block: B:68:0x005f, code lost:
    
        r13.close();
     */
    /* JADX WARN: Code restructure failed: missing block: B:71:0x0057, code lost:
    
        throw r15;
     */
    /* JADX WARN: Finally extract failed */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    public java.sql.ResultSet extractForeignKeyFromCreateTable(java.lang.String r10, java.lang.String r11) throws java.sql.SQLException {
        /*
            Method dump skipped, instructions count: 412
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: com.mysql.jdbc.DatabaseMetaData.extractForeignKeyFromCreateTable(java.lang.String, java.lang.String):java.sql.ResultSet");
    }

    @Override // java.sql.DatabaseMetaData
    public ResultSet getAttributes(String arg0, String arg1, String arg2, String arg3) throws SQLException {
        Field[] fields = {new Field("", "TYPE_CAT", 1, 32), new Field("", "TYPE_SCHEM", 1, 32), new Field("", "TYPE_NAME", 1, 32), new Field("", "ATTR_NAME", 1, 32), new Field("", "DATA_TYPE", FKTABLE_SCHEM, 32), new Field("", "ATTR_TYPE_NAME", 1, 32), new Field("", "ATTR_SIZE", FKTABLE_CAT, 32), new Field("", "DECIMAL_DIGITS", FKTABLE_CAT, 32), new Field("", "NUM_PREC_RADIX", FKTABLE_CAT, 32), new Field("", "NULLABLE ", FKTABLE_CAT, 32), new Field("", "REMARKS", 1, 32), new Field("", "ATTR_DEF", 1, 32), new Field("", "SQL_DATA_TYPE", FKTABLE_CAT, 32), new Field("", "SQL_DATETIME_SUB", FKTABLE_CAT, 32), new Field("", "CHAR_OCTET_LENGTH", FKTABLE_CAT, 32), new Field("", "ORDINAL_POSITION", FKTABLE_CAT, 32), new Field("", "IS_NULLABLE", 1, 32), new Field("", "SCOPE_CATALOG", 1, 32), new Field("", "SCOPE_SCHEMA", 1, 32), new Field("", "SCOPE_TABLE", 1, 32), new Field("", "SOURCE_DATA_TYPE", FKTABLE_SCHEM, 32)};
        return buildResultSet(fields, new ArrayList());
    }

    @Override // java.sql.DatabaseMetaData
    public ResultSet getBestRowIdentifier(String catalog, String schema, String table, int scope, boolean nullable) throws SQLException {
        if (table == null) {
            throw SQLError.createSQLException("Table not specified.", SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
        }
        Field[] fields = {new Field("", "SCOPE", FKTABLE_SCHEM, FKTABLE_SCHEM), new Field("", "COLUMN_NAME", 1, 32), new Field("", "DATA_TYPE", FKTABLE_SCHEM, 32), new Field("", "TYPE_NAME", 1, 32), new Field("", "COLUMN_SIZE", FKTABLE_CAT, DELETE_RULE), new Field("", "BUFFER_LENGTH", FKTABLE_CAT, DELETE_RULE), new Field("", "DECIMAL_DIGITS", FKTABLE_CAT, DELETE_RULE), new Field("", "PSEUDO_COLUMN", FKTABLE_SCHEM, FKTABLE_SCHEM)};
        ArrayList rows = new ArrayList();
        java.sql.Statement stmt = this.conn.getMetadataSafeStatement();
        try {
            new IterateBlock(this, getCatalogIterator(catalog), table, stmt, rows) { // from class: com.mysql.jdbc.DatabaseMetaData.1
                private final String val$table;
                private final java.sql.Statement val$stmt;
                private final ArrayList val$rows;
                private final DatabaseMetaData this$0;

                {
                    this.this$0 = this;
                    this.val$table = table;
                    this.val$stmt = stmt;
                    this.val$rows = rows;
                }

                /*  JADX ERROR: JadxRuntimeException in pass: BlockProcessor
                    jadx.core.utils.exceptions.JadxRuntimeException: Unreachable block: B:29:0x020d
                    	at jadx.core.dex.visitors.blocks.BlockProcessor.checkForUnreachableBlocks(BlockProcessor.java:88)
                    	at jadx.core.dex.visitors.blocks.BlockProcessor.processBlocksTree(BlockProcessor.java:52)
                    	at jadx.core.dex.visitors.blocks.BlockProcessor.visit(BlockProcessor.java:44)
                    */
                @Override // com.mysql.jdbc.DatabaseMetaData.IterateBlock
                void forEach(java.lang.Object r6) throws java.sql.SQLException {
                    /*
                        Method dump skipped, instructions count: 532
                        To view this dump change 'Code comments level' option to 'DEBUG'
                    */
                    throw new UnsupportedOperationException("Method not decompiled: com.mysql.jdbc.DatabaseMetaData.AnonymousClass1.forEach(java.lang.Object):void");
                }
            }.doForAll();
            if (stmt != null) {
                stmt.close();
            }
            ResultSet results = buildResultSet(fields, rows);
            return results;
        } catch (Throwable th) {
            if (stmt != null) {
                stmt.close();
            }
            throw th;
        }
    }

    private void getCallStmtParameterTypes(String catalog, String procName, String parameterNamePattern, List resultRows) throws SQLException {
        getCallStmtParameterTypes(catalog, procName, parameterNamePattern, resultRows, false);
    }

    /*  JADX ERROR: JadxRuntimeException in pass: BlockProcessor
        jadx.core.utils.exceptions.JadxRuntimeException: Unreachable block: B:188:0x03e8
        	at jadx.core.dex.visitors.blocks.BlockProcessor.checkForUnreachableBlocks(BlockProcessor.java:88)
        	at jadx.core.dex.visitors.blocks.BlockProcessor.processBlocksTree(BlockProcessor.java:52)
        	at jadx.core.dex.visitors.blocks.BlockProcessor.visit(BlockProcessor.java:44)
        */
    private void getCallStmtParameterTypes(java.lang.String r12, java.lang.String r13, java.lang.String r14, java.util.List r15, boolean r16) throws java.sql.SQLException {
        /*
            Method dump skipped, instructions count: 1470
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: com.mysql.jdbc.DatabaseMetaData.getCallStmtParameterTypes(java.lang.String, java.lang.String, java.lang.String, java.util.List, boolean):void");
    }

    private int endPositionOfParameterDeclaration(int beginIndex, String procedureDef, String quoteChar) throws SQLException {
        int currentPos = beginIndex + 1;
        int parenDepth = 1;
        while (parenDepth > 0 && currentPos < procedureDef.length()) {
            int closedParenIndex = StringUtils.indexOfIgnoreCaseRespectQuotes(currentPos, procedureDef, ")", quoteChar.charAt(0), !this.conn.isNoBackslashEscapesSet());
            if (closedParenIndex != -1) {
                int nextOpenParenIndex = StringUtils.indexOfIgnoreCaseRespectQuotes(currentPos, procedureDef, "(", quoteChar.charAt(0), !this.conn.isNoBackslashEscapesSet());
                if (nextOpenParenIndex != -1 && nextOpenParenIndex < closedParenIndex) {
                    parenDepth++;
                    currentPos = closedParenIndex + 1;
                } else {
                    parenDepth--;
                    currentPos = closedParenIndex;
                }
            } else {
                throw SQLError.createSQLException("Internal error when parsing callable statement metadata", SQLError.SQL_STATE_GENERAL_ERROR);
            }
        }
        return currentPos;
    }

    private int findEndOfReturnsClause(String procedureDefn, String quoteChar, int positionOfReturnKeyword) throws SQLException {
        String[] tokens = {"LANGUAGE", "NOT", "DETERMINISTIC", "CONTAINS", "NO", "READ", "MODIFIES", "SQL", "COMMENT", "BEGIN", "RETURN"};
        int startLookingAt = positionOfReturnKeyword + "RETURNS".length() + 1;
        for (String str : tokens) {
            int endOfReturn = StringUtils.indexOfIgnoreCaseRespectQuotes(startLookingAt, procedureDefn, str, quoteChar.charAt(0), !this.conn.isNoBackslashEscapesSet());
            if (endOfReturn != -1) {
                return endOfReturn;
            }
        }
        int endOfReturn2 = StringUtils.indexOfIgnoreCaseRespectQuotes(startLookingAt, procedureDefn, ":", quoteChar.charAt(0), !this.conn.isNoBackslashEscapesSet());
        if (endOfReturn2 != -1) {
            for (int i = endOfReturn2; i > 0; i--) {
                if (Character.isWhitespace(procedureDefn.charAt(i))) {
                    return i;
                }
            }
        }
        throw SQLError.createSQLException("Internal error when parsing callable statement metadata", SQLError.SQL_STATE_GENERAL_ERROR);
    }

    private int getCascadeDeleteOption(String cascadeOptions) {
        int onDeletePos = cascadeOptions.indexOf("ON DELETE");
        if (onDeletePos != -1) {
            String deleteOptions = cascadeOptions.substring(onDeletePos, cascadeOptions.length());
            if (deleteOptions.startsWith("ON DELETE CASCADE")) {
                return 0;
            }
            if (deleteOptions.startsWith("ON DELETE SET NULL")) {
                return PKTABLE_NAME;
            }
            if (deleteOptions.startsWith("ON DELETE RESTRICT")) {
                return 1;
            }
            if (deleteOptions.startsWith("ON DELETE NO ACTION")) {
                return PKCOLUMN_NAME;
            }
            return PKCOLUMN_NAME;
        }
        return PKCOLUMN_NAME;
    }

    private int getCascadeUpdateOption(String cascadeOptions) {
        int onUpdatePos = cascadeOptions.indexOf("ON UPDATE");
        if (onUpdatePos != -1) {
            String updateOptions = cascadeOptions.substring(onUpdatePos, cascadeOptions.length());
            if (updateOptions.startsWith("ON UPDATE CASCADE")) {
                return 0;
            }
            if (updateOptions.startsWith("ON UPDATE SET NULL")) {
                return PKTABLE_NAME;
            }
            if (updateOptions.startsWith("ON UPDATE RESTRICT")) {
                return 1;
            }
            if (updateOptions.startsWith("ON UPDATE NO ACTION")) {
                return PKCOLUMN_NAME;
            }
            return PKCOLUMN_NAME;
        }
        return PKCOLUMN_NAME;
    }

    protected IteratorWithCleanup getCatalogIterator(String catalogSpec) throws SQLException {
        IteratorWithCleanup allCatalogsIter;
        if (catalogSpec != null) {
            if (!catalogSpec.equals("")) {
                allCatalogsIter = new SingleStringIterator(this, catalogSpec);
            } else {
                allCatalogsIter = new SingleStringIterator(this, this.database);
            }
        } else if (this.conn.getNullCatalogMeansCurrent()) {
            allCatalogsIter = new SingleStringIterator(this, this.database);
        } else {
            allCatalogsIter = new ResultSetIterator(this, getCatalogs(), 1);
        }
        return allCatalogsIter;
    }

    /*  JADX ERROR: JadxRuntimeException in pass: BlockProcessor
        jadx.core.utils.exceptions.JadxRuntimeException: Unreachable block: B:15:0x00b3
        	at jadx.core.dex.visitors.blocks.BlockProcessor.checkForUnreachableBlocks(BlockProcessor.java:88)
        	at jadx.core.dex.visitors.blocks.BlockProcessor.processBlocksTree(BlockProcessor.java:52)
        	at jadx.core.dex.visitors.blocks.BlockProcessor.visit(BlockProcessor.java:44)
        */
    @Override // java.sql.DatabaseMetaData
    public java.sql.ResultSet getCatalogs() throws java.sql.SQLException {
        /*
            r10 = this;
            r0 = 0
            r11 = r0
            r0 = 0
            r12 = r0
            r0 = r10
            com.mysql.jdbc.ConnectionImpl r0 = r0.conn     // Catch: java.lang.Throwable -> L86
            java.sql.Statement r0 = r0.createStatement()     // Catch: java.lang.Throwable -> L86
            r12 = r0
            r0 = r12
            r1 = 0
            r0.setEscapeProcessing(r1)     // Catch: java.lang.Throwable -> L86
            r0 = r12
            java.lang.String r1 = "SHOW DATABASES"
            java.sql.ResultSet r0 = r0.executeQuery(r1)     // Catch: java.lang.Throwable -> L86
            r11 = r0
            r0 = r11
            java.sql.ResultSetMetaData r0 = r0.getMetaData()     // Catch: java.lang.Throwable -> L86
            r13 = r0
            r0 = 1
            com.mysql.jdbc.Field[] r0 = new com.mysql.jdbc.Field[r0]     // Catch: java.lang.Throwable -> L86
            r14 = r0
            r0 = r14
            r1 = 0
            com.mysql.jdbc.Field r2 = new com.mysql.jdbc.Field     // Catch: java.lang.Throwable -> L86
            r3 = r2
            java.lang.String r4 = ""
            java.lang.String r5 = "TABLE_CAT"
            r6 = 12
            r7 = r13
            r8 = 1
            int r7 = r7.getColumnDisplaySize(r8)     // Catch: java.lang.Throwable -> L86
            r3.<init>(r4, r5, r6, r7)     // Catch: java.lang.Throwable -> L86
            r0[r1] = r2     // Catch: java.lang.Throwable -> L86
            java.util.ArrayList r0 = new java.util.ArrayList     // Catch: java.lang.Throwable -> L86
            r1 = r0
            r1.<init>()     // Catch: java.lang.Throwable -> L86
            r15 = r0
        L4a:
            r0 = r11
            boolean r0 = r0.next()     // Catch: java.lang.Throwable -> L86
            if (r0 == 0) goto L76
            r0 = 1
            byte[] r0 = new byte[r0]     // Catch: java.lang.Throwable -> L86
            r16 = r0
            r0 = r16
            r1 = 0
            r2 = r11
            r3 = 1
            byte[] r2 = r2.getBytes(r3)     // Catch: java.lang.Throwable -> L86
            r0[r1] = r2     // Catch: java.lang.Throwable -> L86
            r0 = r15
            com.mysql.jdbc.ByteArrayRow r1 = new com.mysql.jdbc.ByteArrayRow     // Catch: java.lang.Throwable -> L86
            r2 = r1
            r3 = r16
            r2.<init>(r3)     // Catch: java.lang.Throwable -> L86
            boolean r0 = r0.add(r1)     // Catch: java.lang.Throwable -> L86
            goto L4a
        L76:
            r0 = r10
            r1 = r14
            r2 = r15
            java.sql.ResultSet r0 = r0.buildResultSet(r1, r2)     // Catch: java.lang.Throwable -> L86
            r16 = r0
            r0 = jsr -> L8e
        L83:
            r1 = r16
            return r1
        L86:
            r17 = move-exception
            r0 = jsr -> L8e
        L8b:
            r1 = r17
            throw r1
        L8e:
            r18 = r0
            r0 = r11
            if (r0 == 0) goto La6
            r0 = r11
            r0.close()     // Catch: java.sql.SQLException -> L9d
            goto La4
        L9d:
            r19 = move-exception
            r0 = r19
            com.mysql.jdbc.AssertionFailedException.shouldNotHappen(r0)
        La4:
            r0 = 0
            r11 = r0
        La6:
            r0 = r12
            if (r0 == 0) goto Lbc
            r0 = r12
            r0.close()     // Catch: java.sql.SQLException -> Lb3
            goto Lba
        Lb3:
            r19 = move-exception
            r0 = r19
            com.mysql.jdbc.AssertionFailedException.shouldNotHappen(r0)
        Lba:
            r0 = 0
            r12 = r0
        Lbc:
            ret r18
        */
        throw new UnsupportedOperationException("Method not decompiled: com.mysql.jdbc.DatabaseMetaData.getCatalogs():java.sql.ResultSet");
    }

    @Override // java.sql.DatabaseMetaData
    public String getCatalogSeparator() throws SQLException {
        return ".";
    }

    @Override // java.sql.DatabaseMetaData
    public String getCatalogTerm() throws SQLException {
        return "database";
    }

    /*  JADX ERROR: JadxRuntimeException in pass: BlockProcessor
        jadx.core.utils.exceptions.JadxRuntimeException: Unreachable block: B:39:0x0276
        	at jadx.core.dex.visitors.blocks.BlockProcessor.checkForUnreachableBlocks(BlockProcessor.java:88)
        	at jadx.core.dex.visitors.blocks.BlockProcessor.processBlocksTree(BlockProcessor.java:52)
        	at jadx.core.dex.visitors.blocks.BlockProcessor.visit(BlockProcessor.java:44)
        */
    @Override // java.sql.DatabaseMetaData
    public java.sql.ResultSet getColumnPrivileges(java.lang.String r10, java.lang.String r11, java.lang.String r12, java.lang.String r13) throws java.sql.SQLException {
        /*
            Method dump skipped, instructions count: 646
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: com.mysql.jdbc.DatabaseMetaData.getColumnPrivileges(java.lang.String, java.lang.String, java.lang.String, java.lang.String):java.sql.ResultSet");
    }

    @Override // java.sql.DatabaseMetaData
    public ResultSet getColumns(String catalog, String schemaPattern, String tableNamePattern, String columnNamePattern) throws SQLException {
        if (columnNamePattern == null) {
            if (this.conn.getNullNamePatternMatchesAll()) {
                columnNamePattern = "%";
            } else {
                throw SQLError.createSQLException("Column name pattern can not be NULL or empty.", SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
            }
        }
        String colPattern = columnNamePattern;
        Field[] fields = {new Field("", "TABLE_CAT", 1, 255), new Field("", "TABLE_SCHEM", 1, 0), new Field("", "TABLE_NAME", 1, 255), new Field("", "COLUMN_NAME", 1, 32), new Field("", "DATA_TYPE", FKTABLE_SCHEM, FKTABLE_SCHEM), new Field("", "TYPE_NAME", 1, 16), new Field("", "COLUMN_SIZE", FKTABLE_CAT, Integer.toString(Integer.MAX_VALUE).length()), new Field("", "BUFFER_LENGTH", FKTABLE_CAT, DELETE_RULE), new Field("", "DECIMAL_DIGITS", FKTABLE_CAT, DELETE_RULE), new Field("", "NUM_PREC_RADIX", FKTABLE_CAT, DELETE_RULE), new Field("", "NULLABLE", FKTABLE_CAT, DELETE_RULE), new Field("", "REMARKS", 1, 0), new Field("", "COLUMN_DEF", 1, 0), new Field("", "SQL_DATA_TYPE", FKTABLE_CAT, DELETE_RULE), new Field("", "SQL_DATETIME_SUB", FKTABLE_CAT, DELETE_RULE), new Field("", "CHAR_OCTET_LENGTH", FKTABLE_CAT, Integer.toString(Integer.MAX_VALUE).length()), new Field("", "ORDINAL_POSITION", FKTABLE_CAT, DELETE_RULE), new Field("", "IS_NULLABLE", 1, PKCOLUMN_NAME)};
        ArrayList rows = new ArrayList();
        java.sql.Statement stmt = this.conn.getMetadataSafeStatement();
        try {
            new IterateBlock(this, getCatalogIterator(catalog), tableNamePattern, catalog, schemaPattern, colPattern, stmt, rows) { // from class: com.mysql.jdbc.DatabaseMetaData.2
                private final String val$tableNamePattern;
                private final String val$catalog;
                private final String val$schemaPattern;
                private final String val$colPattern;
                private final java.sql.Statement val$stmt;
                private final ArrayList val$rows;
                private final DatabaseMetaData this$0;

                {
                    this.this$0 = this;
                    this.val$tableNamePattern = tableNamePattern;
                    this.val$catalog = catalog;
                    this.val$schemaPattern = schemaPattern;
                    this.val$colPattern = colPattern;
                    this.val$stmt = stmt;
                    this.val$rows = rows;
                }

                /*  JADX ERROR: JadxRuntimeException in pass: BlockProcessor
                    jadx.core.utils.exceptions.JadxRuntimeException: Unreachable block: B:12:0x0061
                    	at jadx.core.dex.visitors.blocks.BlockProcessor.checkForUnreachableBlocks(BlockProcessor.java:88)
                    	at jadx.core.dex.visitors.blocks.BlockProcessor.processBlocksTree(BlockProcessor.java:52)
                    	at jadx.core.dex.visitors.blocks.BlockProcessor.visit(BlockProcessor.java:44)
                    */
                @Override // com.mysql.jdbc.DatabaseMetaData.IterateBlock
                void forEach(java.lang.Object r8) throws java.sql.SQLException {
                    /*
                        Method dump skipped, instructions count: 1193
                        To view this dump change 'Code comments level' option to 'DEBUG'
                    */
                    throw new UnsupportedOperationException("Method not decompiled: com.mysql.jdbc.DatabaseMetaData.AnonymousClass2.forEach(java.lang.Object):void");
                }
            }.doForAll();
            if (stmt != null) {
                stmt.close();
            }
            ResultSet results = buildResultSet(fields, rows);
            return results;
        } catch (Throwable th) {
            if (stmt != null) {
                stmt.close();
            }
            throw th;
        }
    }

    @Override // java.sql.DatabaseMetaData
    public java.sql.Connection getConnection() throws SQLException {
        return this.conn;
    }

    @Override // java.sql.DatabaseMetaData
    public ResultSet getCrossReference(String primaryCatalog, String primarySchema, String primaryTable, String foreignCatalog, String foreignSchema, String foreignTable) throws SQLException {
        if (primaryTable == null) {
            throw SQLError.createSQLException("Table not specified.", SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
        }
        Field[] fields = {new Field("", "PKTABLE_CAT", 1, 255), new Field("", "PKTABLE_SCHEM", 1, 0), new Field("", "PKTABLE_NAME", 1, 255), new Field("", "PKCOLUMN_NAME", 1, 32), new Field("", "FKTABLE_CAT", 1, 255), new Field("", "FKTABLE_SCHEM", 1, 0), new Field("", "FKTABLE_NAME", 1, 255), new Field("", "FKCOLUMN_NAME", 1, 32), new Field("", "KEY_SEQ", FKTABLE_SCHEM, PKTABLE_NAME), new Field("", "UPDATE_RULE", FKTABLE_SCHEM, PKTABLE_NAME), new Field("", "DELETE_RULE", FKTABLE_SCHEM, PKTABLE_NAME), new Field("", "FK_NAME", 1, 0), new Field("", "PK_NAME", 1, 0), new Field("", "DEFERRABILITY", FKTABLE_CAT, PKTABLE_NAME)};
        ArrayList tuples = new ArrayList();
        if (this.conn.versionMeetsMinimum(PKCOLUMN_NAME, 23, 0)) {
            java.sql.Statement stmt = this.conn.getMetadataSafeStatement();
            try {
                new IterateBlock(this, getCatalogIterator(foreignCatalog), stmt, foreignTable, primaryTable, foreignCatalog, foreignSchema, primaryCatalog, primarySchema, tuples) { // from class: com.mysql.jdbc.DatabaseMetaData.3
                    private final java.sql.Statement val$stmt;
                    private final String val$foreignTable;
                    private final String val$primaryTable;
                    private final String val$foreignCatalog;
                    private final String val$foreignSchema;
                    private final String val$primaryCatalog;
                    private final String val$primarySchema;
                    private final ArrayList val$tuples;
                    private final DatabaseMetaData this$0;

                    {
                        this.this$0 = this;
                        this.val$stmt = stmt;
                        this.val$foreignTable = foreignTable;
                        this.val$primaryTable = primaryTable;
                        this.val$foreignCatalog = foreignCatalog;
                        this.val$foreignSchema = foreignSchema;
                        this.val$primaryCatalog = primaryCatalog;
                        this.val$primarySchema = primarySchema;
                        this.val$tuples = tuples;
                    }

                    /*  JADX ERROR: JadxRuntimeException in pass: BlockProcessor
                        jadx.core.utils.exceptions.JadxRuntimeException: Unreachable block: B:53:0x0289
                        	at jadx.core.dex.visitors.blocks.BlockProcessor.checkForUnreachableBlocks(BlockProcessor.java:88)
                        	at jadx.core.dex.visitors.blocks.BlockProcessor.processBlocksTree(BlockProcessor.java:52)
                        	at jadx.core.dex.visitors.blocks.BlockProcessor.visit(BlockProcessor.java:44)
                        */
                    @Override // com.mysql.jdbc.DatabaseMetaData.IterateBlock
                    void forEach(java.lang.Object r7) throws java.sql.SQLException {
                        /*
                            Method dump skipped, instructions count: 661
                            To view this dump change 'Code comments level' option to 'DEBUG'
                        */
                        throw new UnsupportedOperationException("Method not decompiled: com.mysql.jdbc.DatabaseMetaData.AnonymousClass3.forEach(java.lang.Object):void");
                    }
                }.doForAll();
                if (stmt != null) {
                    stmt.close();
                }
            } catch (Throwable th) {
                if (stmt != null) {
                    stmt.close();
                }
                throw th;
            }
        }
        ResultSet results = buildResultSet(fields, tuples);
        return results;
    }

    @Override // java.sql.DatabaseMetaData
    public int getDatabaseMajorVersion() throws SQLException {
        return this.conn.getServerMajorVersion();
    }

    @Override // java.sql.DatabaseMetaData
    public int getDatabaseMinorVersion() throws SQLException {
        return this.conn.getServerMinorVersion();
    }

    @Override // java.sql.DatabaseMetaData
    public String getDatabaseProductName() throws SQLException {
        return "MySQL";
    }

    @Override // java.sql.DatabaseMetaData
    public String getDatabaseProductVersion() throws SQLException {
        return this.conn.getServerVersion();
    }

    @Override // java.sql.DatabaseMetaData
    public int getDefaultTransactionIsolation() throws SQLException {
        if (this.conn.supportsIsolationLevel()) {
            return PKTABLE_NAME;
        }
        return 0;
    }

    @Override // java.sql.DatabaseMetaData
    public int getDriverMajorVersion() {
        return NonRegisteringDriver.getMajorVersionInternal();
    }

    @Override // java.sql.DatabaseMetaData
    public int getDriverMinorVersion() {
        return NonRegisteringDriver.getMinorVersionInternal();
    }

    @Override // java.sql.DatabaseMetaData
    public String getDriverName() throws SQLException {
        return "MySQL-AB JDBC Driver";
    }

    @Override // java.sql.DatabaseMetaData
    public String getDriverVersion() throws SQLException {
        return "mysql-connector-java-5.1.2-beta ( $Date: 2007-06-15 03:24:27 +0200 (Fri, 15 Jun 2007) $, $Revision: 6451 $ )";
    }

    @Override // java.sql.DatabaseMetaData
    public ResultSet getExportedKeys(String catalog, String schema, String table) throws SQLException {
        if (table == null) {
            throw SQLError.createSQLException("Table not specified.", SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
        }
        Field[] fields = {new Field("", "PKTABLE_CAT", 1, 255), new Field("", "PKTABLE_SCHEM", 1, 0), new Field("", "PKTABLE_NAME", 1, 255), new Field("", "PKCOLUMN_NAME", 1, 32), new Field("", "FKTABLE_CAT", 1, 255), new Field("", "FKTABLE_SCHEM", 1, 0), new Field("", "FKTABLE_NAME", 1, 255), new Field("", "FKCOLUMN_NAME", 1, 32), new Field("", "KEY_SEQ", FKTABLE_SCHEM, PKTABLE_NAME), new Field("", "UPDATE_RULE", FKTABLE_SCHEM, PKTABLE_NAME), new Field("", "DELETE_RULE", FKTABLE_SCHEM, PKTABLE_NAME), new Field("", "FK_NAME", 1, 255), new Field("", "PK_NAME", 1, 0), new Field("", "DEFERRABILITY", FKTABLE_CAT, PKTABLE_NAME)};
        ArrayList rows = new ArrayList();
        if (this.conn.versionMeetsMinimum(PKCOLUMN_NAME, 23, 0)) {
            java.sql.Statement stmt = this.conn.getMetadataSafeStatement();
            try {
                new IterateBlock(this, getCatalogIterator(catalog), stmt, table, rows) { // from class: com.mysql.jdbc.DatabaseMetaData.4
                    private final java.sql.Statement val$stmt;
                    private final String val$table;
                    private final ArrayList val$rows;
                    private final DatabaseMetaData this$0;

                    {
                        this.this$0 = this;
                        this.val$stmt = stmt;
                        this.val$table = table;
                        this.val$rows = rows;
                    }

                    /*  JADX ERROR: JadxRuntimeException in pass: BlockProcessor
                        jadx.core.utils.exceptions.JadxRuntimeException: Unreachable block: B:27:0x010f
                        	at jadx.core.dex.visitors.blocks.BlockProcessor.checkForUnreachableBlocks(BlockProcessor.java:88)
                        	at jadx.core.dex.visitors.blocks.BlockProcessor.processBlocksTree(BlockProcessor.java:52)
                        	at jadx.core.dex.visitors.blocks.BlockProcessor.visit(BlockProcessor.java:44)
                        */
                    @Override // com.mysql.jdbc.DatabaseMetaData.IterateBlock
                    void forEach(java.lang.Object r9) throws java.sql.SQLException {
                        /*
                            Method dump skipped, instructions count: 283
                            To view this dump change 'Code comments level' option to 'DEBUG'
                        */
                        throw new UnsupportedOperationException("Method not decompiled: com.mysql.jdbc.DatabaseMetaData.AnonymousClass4.forEach(java.lang.Object):void");
                    }
                }.doForAll();
                if (stmt != null) {
                    stmt.close();
                }
            } catch (Throwable th) {
                if (stmt != null) {
                    stmt.close();
                }
                throw th;
            }
        }
        ResultSet results = buildResultSet(fields, rows);
        return results;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void getExportKeyResults(String catalog, String exportingTable, String keysComment, List tuples, String fkTableName) throws SQLException {
        getResultsImpl(catalog, exportingTable, keysComment, tuples, fkTableName, true);
    }

    @Override // java.sql.DatabaseMetaData
    public String getExtraNameCharacters() throws SQLException {
        return "#@";
    }

    /* JADX INFO: Access modifiers changed from: private */
    public int[] getForeignKeyActions(String commentString) {
        int[] actions = {PKCOLUMN_NAME, PKCOLUMN_NAME};
        int lastParenIndex = commentString.lastIndexOf(")");
        if (lastParenIndex != commentString.length() - 1) {
            String cascadeOptions = commentString.substring(lastParenIndex + 1).trim().toUpperCase(Locale.ENGLISH);
            actions[0] = getCascadeDeleteOption(cascadeOptions);
            actions[1] = getCascadeUpdateOption(cascadeOptions);
        }
        return actions;
    }

    @Override // java.sql.DatabaseMetaData
    public String getIdentifierQuoteString() throws SQLException {
        if (this.conn.supportsQuotedIdentifiers()) {
            if (!this.conn.useAnsiQuotedIdentifiers()) {
                return "`";
            }
            return "\"";
        }
        return " ";
    }

    @Override // java.sql.DatabaseMetaData
    public ResultSet getImportedKeys(String catalog, String schema, String table) throws SQLException {
        if (table == null) {
            throw SQLError.createSQLException("Table not specified.", SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
        }
        Field[] fields = {new Field("", "PKTABLE_CAT", 1, 255), new Field("", "PKTABLE_SCHEM", 1, 0), new Field("", "PKTABLE_NAME", 1, 255), new Field("", "PKCOLUMN_NAME", 1, 32), new Field("", "FKTABLE_CAT", 1, 255), new Field("", "FKTABLE_SCHEM", 1, 0), new Field("", "FKTABLE_NAME", 1, 255), new Field("", "FKCOLUMN_NAME", 1, 32), new Field("", "KEY_SEQ", FKTABLE_SCHEM, PKTABLE_NAME), new Field("", "UPDATE_RULE", FKTABLE_SCHEM, PKTABLE_NAME), new Field("", "DELETE_RULE", FKTABLE_SCHEM, PKTABLE_NAME), new Field("", "FK_NAME", 1, 255), new Field("", "PK_NAME", 1, 0), new Field("", "DEFERRABILITY", FKTABLE_CAT, PKTABLE_NAME)};
        ArrayList rows = new ArrayList();
        if (this.conn.versionMeetsMinimum(PKCOLUMN_NAME, 23, 0)) {
            java.sql.Statement stmt = this.conn.getMetadataSafeStatement();
            try {
                new IterateBlock(this, getCatalogIterator(catalog), table, stmt, rows) { // from class: com.mysql.jdbc.DatabaseMetaData.5
                    private final String val$table;
                    private final java.sql.Statement val$stmt;
                    private final ArrayList val$rows;
                    private final DatabaseMetaData this$0;

                    {
                        this.this$0 = this;
                        this.val$table = table;
                        this.val$stmt = stmt;
                        this.val$rows = rows;
                    }

                    /*  JADX ERROR: JadxRuntimeException in pass: BlockProcessor
                        jadx.core.utils.exceptions.JadxRuntimeException: Unreachable block: B:26:0x011b
                        	at jadx.core.dex.visitors.blocks.BlockProcessor.checkForUnreachableBlocks(BlockProcessor.java:88)
                        	at jadx.core.dex.visitors.blocks.BlockProcessor.processBlocksTree(BlockProcessor.java:52)
                        	at jadx.core.dex.visitors.blocks.BlockProcessor.visit(BlockProcessor.java:44)
                        */
                    @Override // com.mysql.jdbc.DatabaseMetaData.IterateBlock
                    void forEach(java.lang.Object r7) throws java.sql.SQLException {
                        /*
                            Method dump skipped, instructions count: 295
                            To view this dump change 'Code comments level' option to 'DEBUG'
                        */
                        throw new UnsupportedOperationException("Method not decompiled: com.mysql.jdbc.DatabaseMetaData.AnonymousClass5.forEach(java.lang.Object):void");
                    }
                }.doForAll();
                if (stmt != null) {
                    stmt.close();
                }
            } catch (Throwable th) {
                if (stmt != null) {
                    stmt.close();
                }
                throw th;
            }
        }
        ResultSet results = buildResultSet(fields, rows);
        return results;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void getImportKeyResults(String catalog, String importingTable, String keysComment, List tuples) throws SQLException {
        getResultsImpl(catalog, importingTable, keysComment, tuples, null, false);
    }

    @Override // java.sql.DatabaseMetaData
    public ResultSet getIndexInfo(String catalog, String schema, String table, boolean unique, boolean approximate) throws SQLException {
        Field[] fields = {new Field("", "TABLE_CAT", 1, 255), new Field("", "TABLE_SCHEM", 1, 0), new Field("", "TABLE_NAME", 1, 255), new Field("", "NON_UNIQUE", 1, FKTABLE_CAT), new Field("", "INDEX_QUALIFIER", 1, 1), new Field("", "INDEX_NAME", 1, 32), new Field("", "TYPE", 1, 32), new Field("", "ORDINAL_POSITION", FKTABLE_SCHEM, FKTABLE_SCHEM), new Field("", "COLUMN_NAME", 1, 32), new Field("", "ASC_OR_DESC", 1, 1), new Field("", "CARDINALITY", FKTABLE_CAT, DELETE_RULE), new Field("", "PAGES", FKTABLE_CAT, DELETE_RULE), new Field("", "FILTER_CONDITION", 1, 32)};
        ArrayList rows = new ArrayList();
        java.sql.Statement stmt = this.conn.getMetadataSafeStatement();
        try {
            new IterateBlock(this, getCatalogIterator(catalog), table, stmt, unique, rows) { // from class: com.mysql.jdbc.DatabaseMetaData.6
                private final String val$table;
                private final java.sql.Statement val$stmt;
                private final boolean val$unique;
                private final ArrayList val$rows;
                private final DatabaseMetaData this$0;

                {
                    this.this$0 = this;
                    this.val$table = table;
                    this.val$stmt = stmt;
                    this.val$unique = unique;
                    this.val$rows = rows;
                }

                /*  JADX ERROR: JadxRuntimeException in pass: BlockProcessor
                    jadx.core.utils.exceptions.JadxRuntimeException: Unreachable block: B:31:0x01b0
                    	at jadx.core.dex.visitors.blocks.BlockProcessor.checkForUnreachableBlocks(BlockProcessor.java:88)
                    	at jadx.core.dex.visitors.blocks.BlockProcessor.processBlocksTree(BlockProcessor.java:52)
                    	at jadx.core.dex.visitors.blocks.BlockProcessor.visit(BlockProcessor.java:44)
                    */
                @Override // com.mysql.jdbc.DatabaseMetaData.IterateBlock
                void forEach(java.lang.Object r6) throws java.sql.SQLException {
                    /*
                        Method dump skipped, instructions count: 439
                        To view this dump change 'Code comments level' option to 'DEBUG'
                    */
                    throw new UnsupportedOperationException("Method not decompiled: com.mysql.jdbc.DatabaseMetaData.AnonymousClass6.forEach(java.lang.Object):void");
                }
            }.doForAll();
            ResultSet indexInfo = buildResultSet(fields, rows);
            if (stmt != null) {
                stmt.close();
            }
            return indexInfo;
        } catch (Throwable th) {
            if (stmt != null) {
                stmt.close();
            }
            throw th;
        }
    }

    @Override // java.sql.DatabaseMetaData
    public int getJDBCMajorVersion() throws SQLException {
        return PKCOLUMN_NAME;
    }

    @Override // java.sql.DatabaseMetaData
    public int getJDBCMinorVersion() throws SQLException {
        return 0;
    }

    @Override // java.sql.DatabaseMetaData
    public int getMaxBinaryLiteralLength() throws SQLException {
        return 16777208;
    }

    @Override // java.sql.DatabaseMetaData
    public int getMaxCatalogNameLength() throws SQLException {
        return 32;
    }

    @Override // java.sql.DatabaseMetaData
    public int getMaxCharLiteralLength() throws SQLException {
        return 16777208;
    }

    @Override // java.sql.DatabaseMetaData
    public int getMaxColumnNameLength() throws SQLException {
        return MAX_IDENTIFIER_LENGTH;
    }

    @Override // java.sql.DatabaseMetaData
    public int getMaxColumnsInGroupBy() throws SQLException {
        return MAX_IDENTIFIER_LENGTH;
    }

    @Override // java.sql.DatabaseMetaData
    public int getMaxColumnsInIndex() throws SQLException {
        return 16;
    }

    @Override // java.sql.DatabaseMetaData
    public int getMaxColumnsInOrderBy() throws SQLException {
        return MAX_IDENTIFIER_LENGTH;
    }

    @Override // java.sql.DatabaseMetaData
    public int getMaxColumnsInSelect() throws SQLException {
        return 256;
    }

    @Override // java.sql.DatabaseMetaData
    public int getMaxColumnsInTable() throws SQLException {
        return 512;
    }

    @Override // java.sql.DatabaseMetaData
    public int getMaxConnections() throws SQLException {
        return 0;
    }

    @Override // java.sql.DatabaseMetaData
    public int getMaxCursorNameLength() throws SQLException {
        return MAX_IDENTIFIER_LENGTH;
    }

    @Override // java.sql.DatabaseMetaData
    public int getMaxIndexLength() throws SQLException {
        return 256;
    }

    @Override // java.sql.DatabaseMetaData
    public int getMaxProcedureNameLength() throws SQLException {
        return 0;
    }

    @Override // java.sql.DatabaseMetaData
    public int getMaxRowSize() throws SQLException {
        return 2147483639;
    }

    @Override // java.sql.DatabaseMetaData
    public int getMaxSchemaNameLength() throws SQLException {
        return 0;
    }

    @Override // java.sql.DatabaseMetaData
    public int getMaxStatementLength() throws SQLException {
        return MysqlIO.getMaxBuf() - FKTABLE_CAT;
    }

    @Override // java.sql.DatabaseMetaData
    public int getMaxStatements() throws SQLException {
        return 0;
    }

    @Override // java.sql.DatabaseMetaData
    public int getMaxTableNameLength() throws SQLException {
        return MAX_IDENTIFIER_LENGTH;
    }

    @Override // java.sql.DatabaseMetaData
    public int getMaxTablesInSelect() throws SQLException {
        return 256;
    }

    @Override // java.sql.DatabaseMetaData
    public int getMaxUserNameLength() throws SQLException {
        return 16;
    }

    @Override // java.sql.DatabaseMetaData
    public String getNumericFunctions() throws SQLException {
        return "ABS,ACOS,ASIN,ATAN,ATAN2,BIT_COUNT,CEILING,COS,COT,DEGREES,EXP,FLOOR,LOG,LOG10,MAX,MIN,MOD,PI,POW,POWER,RADIANS,RAND,ROUND,SIN,SQRT,TAN,TRUNCATE";
    }

    @Override // java.sql.DatabaseMetaData
    public ResultSet getPrimaryKeys(String catalog, String schema, String table) throws SQLException {
        Field[] fields = {new Field("", "TABLE_CAT", 1, 255), new Field("", "TABLE_SCHEM", 1, 0), new Field("", "TABLE_NAME", 1, 255), new Field("", "COLUMN_NAME", 1, 32), new Field("", "KEY_SEQ", FKTABLE_SCHEM, FKTABLE_SCHEM), new Field("", "PK_NAME", 1, 32)};
        if (table == null) {
            throw SQLError.createSQLException("Table not specified.", SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
        }
        ArrayList rows = new ArrayList();
        java.sql.Statement stmt = this.conn.getMetadataSafeStatement();
        try {
            new IterateBlock(this, getCatalogIterator(catalog), table, stmt, rows) { // from class: com.mysql.jdbc.DatabaseMetaData.7
                private final String val$table;
                private final java.sql.Statement val$stmt;
                private final ArrayList val$rows;
                private final DatabaseMetaData this$0;

                {
                    this.this$0 = this;
                    this.val$table = table;
                    this.val$stmt = stmt;
                    this.val$rows = rows;
                }

                /*  JADX ERROR: JadxRuntimeException in pass: BlockProcessor
                    jadx.core.utils.exceptions.JadxRuntimeException: Unreachable block: B:25:0x0162
                    	at jadx.core.dex.visitors.blocks.BlockProcessor.checkForUnreachableBlocks(BlockProcessor.java:88)
                    	at jadx.core.dex.visitors.blocks.BlockProcessor.processBlocksTree(BlockProcessor.java:52)
                    	at jadx.core.dex.visitors.blocks.BlockProcessor.visit(BlockProcessor.java:44)
                    */
                @Override // com.mysql.jdbc.DatabaseMetaData.IterateBlock
                void forEach(java.lang.Object r7) throws java.sql.SQLException {
                    /*
                        Method dump skipped, instructions count: 361
                        To view this dump change 'Code comments level' option to 'DEBUG'
                    */
                    throw new UnsupportedOperationException("Method not decompiled: com.mysql.jdbc.DatabaseMetaData.AnonymousClass7.forEach(java.lang.Object):void");
                }
            }.doForAll();
            if (stmt != null) {
                stmt.close();
            }
            ResultSet results = buildResultSet(fields, rows);
            return results;
        } catch (Throwable th) {
            if (stmt != null) {
                stmt.close();
            }
            throw th;
        }
    }

    @Override // java.sql.DatabaseMetaData
    public ResultSet getProcedureColumns(String catalog, String schemaPattern, String procedureNamePattern, String columnNamePattern) throws SQLException {
        Field[] fields = {new Field("", "PROCEDURE_CAT", 1, 0), new Field("", "PROCEDURE_SCHEM", 1, 0), new Field("", "PROCEDURE_NAME", 1, 0), new Field("", "COLUMN_NAME", 1, 0), new Field("", "COLUMN_TYPE", 1, 0), new Field("", "DATA_TYPE", FKTABLE_SCHEM, 0), new Field("", "TYPE_NAME", 1, 0), new Field("", "PRECISION", FKTABLE_CAT, 0), new Field("", "LENGTH", FKTABLE_CAT, 0), new Field("", "SCALE", FKTABLE_SCHEM, 0), new Field("", "RADIX", FKTABLE_SCHEM, 0), new Field("", "NULLABLE", FKTABLE_SCHEM, 0), new Field("", "REMARKS", 1, 0)};
        return getProcedureOrFunctionColumns(fields, catalog, schemaPattern, procedureNamePattern, columnNamePattern, true, true);
    }

    /*  JADX ERROR: JadxRuntimeException in pass: BlockProcessor
        jadx.core.utils.exceptions.JadxRuntimeException: Unreachable block: B:23:0x008d
        	at jadx.core.dex.visitors.blocks.BlockProcessor.checkForUnreachableBlocks(BlockProcessor.java:88)
        	at jadx.core.dex.visitors.blocks.BlockProcessor.processBlocksTree(BlockProcessor.java:52)
        	at jadx.core.dex.visitors.blocks.BlockProcessor.visit(BlockProcessor.java:44)
        */
    protected java.sql.ResultSet getProcedureOrFunctionColumns(com.mysql.jdbc.Field[] r9, java.lang.String r10, java.lang.String r11, java.lang.String r12, java.lang.String r13, boolean r14, boolean r15) throws java.sql.SQLException {
        /*
            r8 = this;
            java.util.ArrayList r0 = new java.util.ArrayList
            r1 = r0
            r1.<init>()
            r16 = r0
            r0 = r8
            boolean r0 = r0.supportsStoredProcedures()
            if (r0 == 0) goto L9d
            r0 = r12
            java.lang.String r1 = "%"
            int r0 = r0.indexOf(r1)
            r1 = -1
            if (r0 != r1) goto L34
            r0 = r12
            java.lang.String r1 = "?"
            int r0 = r0.indexOf(r1)
            r1 = -1
            if (r0 != r1) goto L34
            r0 = r16
            r1 = r12
            boolean r0 = r0.add(r1)
            goto L9d
        L34:
            r0 = 0
            r17 = r0
            r0 = r8
            r1 = r8
            com.mysql.jdbc.Field[] r1 = r1.createFieldMetadataForGetProcedures()     // Catch: java.lang.Throwable -> L71
            r2 = r10
            r3 = r11
            r4 = r12
            r5 = r14
            r6 = r15
            java.sql.ResultSet r0 = r0.getProceduresAndOrFunctions(r1, r2, r3, r4, r5, r6)     // Catch: java.lang.Throwable -> L71
            r17 = r0
        L49:
            r0 = r17
            boolean r0 = r0.next()     // Catch: java.lang.Throwable -> L71
            if (r0 == 0) goto L66
            r0 = r16
            r1 = r17
            r2 = 3
            java.lang.String r1 = r1.getString(r2)     // Catch: java.lang.Throwable -> L71
            boolean r0 = r0.add(r1)     // Catch: java.lang.Throwable -> L71
            goto L49
        L66:
            r0 = r16
            java.util.Collections.sort(r0)     // Catch: java.lang.Throwable -> L71
            r0 = jsr -> L79
        L6e:
            goto L9d
        L71:
            r18 = move-exception
            r0 = jsr -> L79
        L76:
            r1 = r18
            throw r1
        L79:
            r19 = r0
            r0 = 0
            r20 = r0
            r0 = r17
            if (r0 == 0) goto L93
            r0 = r17
            r0.close()     // Catch: java.sql.SQLException -> L8d
            goto L93
        L8d:
            r21 = move-exception
            r0 = r21
            r20 = r0
        L93:
            r0 = r20
            if (r0 == 0) goto L9b
            r0 = r20
            throw r0
        L9b:
            ret r19
        L9d:
            java.util.ArrayList r0 = new java.util.ArrayList
            r1 = r0
            r1.<init>()
            r17 = r0
            r0 = r16
            java.util.Iterator r0 = r0.iterator()
            r18 = r0
        Laf:
            r0 = r18
            boolean r0 = r0.hasNext()
            if (r0 == 0) goto Ldf
            r0 = r18
            java.lang.Object r0 = r0.next()
            java.lang.String r0 = (java.lang.String) r0
            r19 = r0
            r0 = r8
            r1 = r10
            r2 = r19
            r3 = r13
            r4 = r17
            r5 = r9
            int r5 = r5.length
            r6 = 17
            if (r5 != r6) goto Ld8
            r5 = 1
            goto Ld9
        Ld8:
            r5 = 0
        Ld9:
            r0.getCallStmtParameterTypes(r1, r2, r3, r4, r5)
            goto Laf
        Ldf:
            r0 = r8
            r1 = r9
            r2 = r17
            java.sql.ResultSet r0 = r0.buildResultSet(r1, r2)
            return r0
        */
        throw new UnsupportedOperationException("Method not decompiled: com.mysql.jdbc.DatabaseMetaData.getProcedureOrFunctionColumns(com.mysql.jdbc.Field[], java.lang.String, java.lang.String, java.lang.String, java.lang.String, boolean, boolean):java.sql.ResultSet");
    }

    @Override // java.sql.DatabaseMetaData
    public ResultSet getProcedures(String catalog, String schemaPattern, String procedureNamePattern) throws SQLException {
        Field[] fields = createFieldMetadataForGetProcedures();
        return getProceduresAndOrFunctions(fields, catalog, schemaPattern, procedureNamePattern, true, true);
    }

    private Field[] createFieldMetadataForGetProcedures() {
        Field[] fields = {new Field("", "PROCEDURE_CAT", 1, 0), new Field("", "PROCEDURE_SCHEM", 1, 0), new Field("", "PROCEDURE_NAME", 1, 0), new Field("", "reserved1", 1, 0), new Field("", "reserved2", 1, 0), new Field("", "reserved3", 1, 0), new Field("", "REMARKS", 1, 0), new Field("", "PROCEDURE_TYPE", FKTABLE_SCHEM, 0)};
        return fields;
    }

    protected ResultSet getProceduresAndOrFunctions(Field[] fields, String catalog, String schemaPattern, String procedureNamePattern, boolean returnProcedures, boolean returnFunctions) throws SQLException {
        if (procedureNamePattern == null || procedureNamePattern.length() == 0) {
            if (this.conn.getNullNamePatternMatchesAll()) {
                procedureNamePattern = "%";
            } else {
                throw SQLError.createSQLException("Procedure name pattern can not be NULL or empty.", SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
            }
        }
        ArrayList procedureRows = new ArrayList();
        if (supportsStoredProcedures()) {
            String procNamePattern = procedureNamePattern;
            Map procedureRowsOrderedByName = new TreeMap();
            new IterateBlock(this, getCatalogIterator(catalog), procNamePattern, returnProcedures, procedureRowsOrderedByName, returnFunctions, fields, procedureRows) { // from class: com.mysql.jdbc.DatabaseMetaData.8
                private final String val$procNamePattern;
                private final boolean val$returnProcedures;
                private final Map val$procedureRowsOrderedByName;
                private final boolean val$returnFunctions;
                private final Field[] val$fields;
                private final ArrayList val$procedureRows;
                private final DatabaseMetaData this$0;

                {
                    this.this$0 = this;
                    this.val$procNamePattern = procNamePattern;
                    this.val$returnProcedures = returnProcedures;
                    this.val$procedureRowsOrderedByName = procedureRowsOrderedByName;
                    this.val$returnFunctions = returnFunctions;
                    this.val$fields = fields;
                    this.val$procedureRows = procedureRows;
                }

                /*  JADX ERROR: JadxRuntimeException in pass: BlockProcessor
                    jadx.core.utils.exceptions.JadxRuntimeException: Unreachable block: B:41:0x0186
                    	at jadx.core.dex.visitors.blocks.BlockProcessor.checkForUnreachableBlocks(BlockProcessor.java:88)
                    	at jadx.core.dex.visitors.blocks.BlockProcessor.processBlocksTree(BlockProcessor.java:52)
                    	at jadx.core.dex.visitors.blocks.BlockProcessor.visit(BlockProcessor.java:44)
                    */
                @Override // com.mysql.jdbc.DatabaseMetaData.IterateBlock
                void forEach(java.lang.Object r10) throws java.sql.SQLException {
                    /*
                        Method dump skipped, instructions count: 407
                        To view this dump change 'Code comments level' option to 'DEBUG'
                    */
                    throw new UnsupportedOperationException("Method not decompiled: com.mysql.jdbc.DatabaseMetaData.AnonymousClass8.forEach(java.lang.Object):void");
                }
            }.doForAll();
        }
        return buildResultSet(fields, procedureRows);
    }

    @Override // java.sql.DatabaseMetaData
    public String getProcedureTerm() throws SQLException {
        return "PROCEDURE";
    }

    @Override // java.sql.DatabaseMetaData
    public int getResultSetHoldability() throws SQLException {
        return 1;
    }

    /* JADX WARN: Type inference failed for: r0v16, types: [byte[], byte[][]] */
    private void getResultsImpl(String catalog, String table, String keysComment, List tuples, String fkTableName, boolean isExport) throws SQLException {
        LocalAndReferencedColumns parsedInfo = parseTableStatusIntoLocalAndReferencedColumns(keysComment);
        if (isExport && !parsedInfo.referencedTable.equals(table)) {
            return;
        }
        if (parsedInfo.localColumnsList.size() != parsedInfo.referencedColumnsList.size()) {
            throw SQLError.createSQLException("Error parsing foreign keys definition,number of local and referenced columns is not the same.", SQLError.SQL_STATE_GENERAL_ERROR);
        }
        Iterator localColumnNames = parsedInfo.localColumnsList.iterator();
        Iterator referColumnNames = parsedInfo.referencedColumnsList.iterator();
        int keySeqIndex = 1;
        while (localColumnNames.hasNext()) {
            ?? r0 = new byte[14];
            String lColumnName = removeQuotedId(localColumnNames.next().toString());
            String rColumnName = removeQuotedId(referColumnNames.next().toString());
            r0[FKTABLE_CAT] = catalog == null ? new byte[0] : s2b(catalog);
            r0[FKTABLE_SCHEM] = 0;
            r0[FKTABLE_NAME] = s2b(isExport ? fkTableName : table);
            r0[FKCOLUMN_NAME] = s2b(lColumnName);
            r0[0] = s2b(parsedInfo.referencedCatalog);
            r0[1] = 0;
            r0[PKTABLE_NAME] = s2b(isExport ? table : parsedInfo.referencedTable);
            r0[PKCOLUMN_NAME] = s2b(rColumnName);
            int i = keySeqIndex;
            keySeqIndex++;
            r0[KEY_SEQ] = s2b(Integer.toString(i));
            int[] actions = getForeignKeyActions(keysComment);
            r0[UPDATE_RULE] = s2b(Integer.toString(actions[1]));
            r0[DELETE_RULE] = s2b(Integer.toString(actions[0]));
            r0[FK_NAME] = s2b(parsedInfo.constraintName);
            r0[PK_NAME] = 0;
            r0[DEFERRABILITY] = s2b(Integer.toString(FKCOLUMN_NAME));
            tuples.add(new ByteArrayRow(r0));
        }
    }

    @Override // java.sql.DatabaseMetaData
    public ResultSet getSchemas() throws SQLException {
        Field[] fields = {new Field("", "TABLE_SCHEM", 1, 0), new Field("", "TABLE_CATALOG", 1, 0)};
        ArrayList tuples = new ArrayList();
        ResultSet results = buildResultSet(fields, tuples);
        return results;
    }

    @Override // java.sql.DatabaseMetaData
    public String getSchemaTerm() throws SQLException {
        return "";
    }

    @Override // java.sql.DatabaseMetaData
    public String getSearchStringEscape() throws SQLException {
        return "\\";
    }

    @Override // java.sql.DatabaseMetaData
    public String getSQLKeywords() throws SQLException {
        return mysqlKeywordsThatArentSQL92;
    }

    @Override // java.sql.DatabaseMetaData
    public int getSQLStateType() throws SQLException {
        if (this.conn.versionMeetsMinimum(FKTABLE_CAT, 1, 0)) {
            return PKTABLE_NAME;
        }
        if (this.conn.getUseSqlStateCodes()) {
            return PKTABLE_NAME;
        }
        return 1;
    }

    @Override // java.sql.DatabaseMetaData
    public String getStringFunctions() throws SQLException {
        return "ASCII,BIN,BIT_LENGTH,CHAR,CHARACTER_LENGTH,CHAR_LENGTH,CONCAT,CONCAT_WS,CONV,ELT,EXPORT_SET,FIELD,FIND_IN_SET,HEX,INSERT,INSTR,LCASE,LEFT,LENGTH,LOAD_FILE,LOCATE,LOCATE,LOWER,LPAD,LTRIM,MAKE_SET,MATCH,MID,OCT,OCTET_LENGTH,ORD,POSITION,QUOTE,REPEAT,REPLACE,REVERSE,RIGHT,RPAD,RTRIM,SOUNDEX,SPACE,STRCMP,SUBSTRING,SUBSTRING,SUBSTRING,SUBSTRING,SUBSTRING_INDEX,TRIM,UCASE,UPPER";
    }

    @Override // java.sql.DatabaseMetaData
    public ResultSet getSuperTables(String arg0, String arg1, String arg2) throws SQLException {
        Field[] fields = {new Field("", "TABLE_CAT", 1, 32), new Field("", "TABLE_SCHEM", 1, 32), new Field("", "TABLE_NAME", 1, 32), new Field("", "SUPERTABLE_NAME", 1, 32)};
        return buildResultSet(fields, new ArrayList());
    }

    @Override // java.sql.DatabaseMetaData
    public ResultSet getSuperTypes(String arg0, String arg1, String arg2) throws SQLException {
        Field[] fields = {new Field("", "TABLE_CAT", 1, 32), new Field("", "TABLE_SCHEM", 1, 32), new Field("", "TYPE_NAME", 1, 32), new Field("", "SUPERTYPE_CAT", 1, 32), new Field("", "SUPERTYPE_SCHEM", 1, 32), new Field("", "SUPERTYPE_NAME", 1, 32)};
        return buildResultSet(fields, new ArrayList());
    }

    @Override // java.sql.DatabaseMetaData
    public String getSystemFunctions() throws SQLException {
        return "DATABASE,USER,SYSTEM_USER,SESSION_USER,PASSWORD,ENCRYPT,LAST_INSERT_ID,VERSION";
    }

    /* JADX INFO: Access modifiers changed from: private */
    public String getTableNameWithCase(String table) {
        String tableNameWithCase = this.conn.lowerCaseTableNames() ? table.toLowerCase() : table;
        return tableNameWithCase;
    }

    /*  JADX ERROR: JadxRuntimeException in pass: BlockProcessor
        jadx.core.utils.exceptions.JadxRuntimeException: Unreachable block: B:44:0x026f
        	at jadx.core.dex.visitors.blocks.BlockProcessor.checkForUnreachableBlocks(BlockProcessor.java:88)
        	at jadx.core.dex.visitors.blocks.BlockProcessor.processBlocksTree(BlockProcessor.java:52)
        	at jadx.core.dex.visitors.blocks.BlockProcessor.visit(BlockProcessor.java:44)
        */
    @Override // java.sql.DatabaseMetaData
    public java.sql.ResultSet getTablePrivileges(java.lang.String r10, java.lang.String r11, java.lang.String r12) throws java.sql.SQLException {
        /*
            Method dump skipped, instructions count: 700
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: com.mysql.jdbc.DatabaseMetaData.getTablePrivileges(java.lang.String, java.lang.String, java.lang.String):java.sql.ResultSet");
    }

    @Override // java.sql.DatabaseMetaData
    public ResultSet getTables(String catalog, String schemaPattern, String tableNamePattern, String[] types) throws SQLException {
        if (tableNamePattern == null) {
            if (this.conn.getNullNamePatternMatchesAll()) {
                tableNamePattern = "%";
            } else {
                throw SQLError.createSQLException("Table name pattern can not be NULL or empty.", SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
            }
        }
        Field[] fields = {new Field("", "TABLE_CAT", PK_NAME, 255), new Field("", "TABLE_SCHEM", PK_NAME, 0), new Field("", "TABLE_NAME", PK_NAME, 255), new Field("", "TABLE_TYPE", PK_NAME, FKTABLE_SCHEM), new Field("", "REMARKS", PK_NAME, 0)};
        ArrayList tuples = new ArrayList();
        java.sql.Statement stmt = this.conn.getMetadataSafeStatement();
        String tableNamePat = tableNamePattern;
        try {
            new IterateBlock(this, getCatalogIterator(catalog), stmt, tableNamePat, types, tuples) { // from class: com.mysql.jdbc.DatabaseMetaData.9
                private final java.sql.Statement val$stmt;
                private final String val$tableNamePat;
                private final String[] val$types;
                private final ArrayList val$tuples;
                private final DatabaseMetaData this$0;

                {
                    this.this$0 = this;
                    this.val$stmt = stmt;
                    this.val$tableNamePat = tableNamePat;
                    this.val$types = types;
                    this.val$tuples = tuples;
                }

                /*  JADX ERROR: JadxRuntimeException in pass: BlockProcessor
                    jadx.core.utils.exceptions.JadxRuntimeException: Unreachable block: B:98:0x0303
                    	at jadx.core.dex.visitors.blocks.BlockProcessor.checkForUnreachableBlocks(BlockProcessor.java:88)
                    	at jadx.core.dex.visitors.blocks.BlockProcessor.processBlocksTree(BlockProcessor.java:52)
                    	at jadx.core.dex.visitors.blocks.BlockProcessor.visit(BlockProcessor.java:44)
                    */
                @Override // com.mysql.jdbc.DatabaseMetaData.IterateBlock
                void forEach(java.lang.Object r6) throws java.sql.SQLException {
                    /*
                        Method dump skipped, instructions count: 778
                        To view this dump change 'Code comments level' option to 'DEBUG'
                    */
                    throw new UnsupportedOperationException("Method not decompiled: com.mysql.jdbc.DatabaseMetaData.AnonymousClass9.forEach(java.lang.Object):void");
                }
            }.doForAll();
            if (stmt != null) {
                stmt.close();
            }
            ResultSet tables = buildResultSet(fields, tuples);
            return tables;
        } catch (Throwable th) {
            if (stmt != null) {
                stmt.close();
            }
            throw th;
        }
    }

    /* JADX WARN: Type inference failed for: r0v13, types: [byte[], byte[][]] */
    /* JADX WARN: Type inference failed for: r0v20, types: [byte[], byte[][]] */
    /* JADX WARN: Type inference failed for: r0v5, types: [byte[], byte[][]] */
    @Override // java.sql.DatabaseMetaData
    public ResultSet getTableTypes() throws SQLException {
        ArrayList tuples = new ArrayList();
        Field[] fields = {new Field("", "TABLE_TYPE", PK_NAME, FKTABLE_SCHEM)};
        tuples.add(new ByteArrayRow(new byte[]{TABLE_AS_BYTES}));
        if (this.conn.versionMeetsMinimum(FKTABLE_SCHEM, 0, 1)) {
            tuples.add(new ByteArrayRow(new byte[]{VIEW_AS_BYTES}));
        }
        tuples.add(new ByteArrayRow(new byte[]{s2b("LOCAL TEMPORARY")}));
        return buildResultSet(fields, tuples);
    }

    @Override // java.sql.DatabaseMetaData
    public String getTimeDateFunctions() throws SQLException {
        return "DAYOFWEEK,WEEKDAY,DAYOFMONTH,DAYOFYEAR,MONTH,DAYNAME,MONTHNAME,QUARTER,WEEK,YEAR,HOUR,MINUTE,SECOND,PERIOD_ADD,PERIOD_DIFF,TO_DAYS,FROM_DAYS,DATE_FORMAT,TIME_FORMAT,CURDATE,CURRENT_DATE,CURTIME,CURRENT_TIME,NOW,SYSDATE,CURRENT_TIMESTAMP,UNIX_TIMESTAMP,FROM_UNIXTIME,SEC_TO_TIME,TIME_TO_SEC";
    }

    /* JADX WARN: Type inference failed for: r0v112, types: [byte[], byte[][]] */
    /* JADX WARN: Type inference failed for: r0v134, types: [byte[], byte[][]] */
    /* JADX WARN: Type inference failed for: r0v156, types: [byte[], byte[][]] */
    /* JADX WARN: Type inference failed for: r0v178, types: [byte[], byte[][]] */
    /* JADX WARN: Type inference failed for: r0v200, types: [byte[], byte[][]] */
    /* JADX WARN: Type inference failed for: r0v222, types: [byte[], byte[][]] */
    /* JADX WARN: Type inference failed for: r0v24, types: [byte[], byte[][]] */
    /* JADX WARN: Type inference failed for: r0v244, types: [byte[], byte[][]] */
    /* JADX WARN: Type inference failed for: r0v266, types: [byte[], byte[][]] */
    /* JADX WARN: Type inference failed for: r0v288, types: [byte[], byte[][]] */
    /* JADX WARN: Type inference failed for: r0v310, types: [byte[], byte[][]] */
    /* JADX WARN: Type inference failed for: r0v332, types: [byte[], byte[][]] */
    /* JADX WARN: Type inference failed for: r0v354, types: [byte[], byte[][]] */
    /* JADX WARN: Type inference failed for: r0v376, types: [byte[], byte[][]] */
    /* JADX WARN: Type inference failed for: r0v398, types: [byte[], byte[][]] */
    /* JADX WARN: Type inference failed for: r0v420, types: [byte[], byte[][]] */
    /* JADX WARN: Type inference failed for: r0v442, types: [byte[], byte[][]] */
    /* JADX WARN: Type inference failed for: r0v46, types: [byte[], byte[][]] */
    /* JADX WARN: Type inference failed for: r0v464, types: [byte[], byte[][]] */
    /* JADX WARN: Type inference failed for: r0v486, types: [byte[], byte[][]] */
    /* JADX WARN: Type inference failed for: r0v508, types: [byte[], byte[][]] */
    /* JADX WARN: Type inference failed for: r0v530, types: [byte[], byte[][]] */
    /* JADX WARN: Type inference failed for: r0v552, types: [byte[], byte[][]] */
    /* JADX WARN: Type inference failed for: r0v574, types: [byte[], byte[][]] */
    /* JADX WARN: Type inference failed for: r0v596, types: [byte[], byte[][]] */
    /* JADX WARN: Type inference failed for: r0v618, types: [byte[], byte[][]] */
    /* JADX WARN: Type inference failed for: r0v640, types: [byte[], byte[][]] */
    /* JADX WARN: Type inference failed for: r0v662, types: [byte[], byte[][]] */
    /* JADX WARN: Type inference failed for: r0v68, types: [byte[], byte[][]] */
    /* JADX WARN: Type inference failed for: r0v684, types: [byte[], byte[][]] */
    /* JADX WARN: Type inference failed for: r0v706, types: [byte[], byte[][]] */
    /* JADX WARN: Type inference failed for: r0v728, types: [byte[], byte[][]] */
    /* JADX WARN: Type inference failed for: r0v750, types: [byte[], byte[][]] */
    /* JADX WARN: Type inference failed for: r0v90, types: [byte[], byte[][]] */
    @Override // java.sql.DatabaseMetaData
    public ResultSet getTypeInfo() throws SQLException {
        Field[] fields = {new Field("", "TYPE_NAME", 1, 32), new Field("", "DATA_TYPE", FKTABLE_SCHEM, FKTABLE_SCHEM), new Field("", "PRECISION", FKTABLE_CAT, DELETE_RULE), new Field("", "LITERAL_PREFIX", 1, FKTABLE_CAT), new Field("", "LITERAL_SUFFIX", 1, FKTABLE_CAT), new Field("", "CREATE_PARAMS", 1, 32), new Field("", "NULLABLE", FKTABLE_SCHEM, FKTABLE_SCHEM), new Field("", "CASE_SENSITIVE", 1, PKCOLUMN_NAME), new Field("", "SEARCHABLE", FKTABLE_SCHEM, PKCOLUMN_NAME), new Field("", "UNSIGNED_ATTRIBUTE", 1, PKCOLUMN_NAME), new Field("", "FIXED_PREC_SCALE", 1, PKCOLUMN_NAME), new Field("", "AUTO_INCREMENT", 1, PKCOLUMN_NAME), new Field("", "LOCAL_TYPE_NAME", 1, 32), new Field("", "MINIMUM_SCALE", FKTABLE_SCHEM, FKTABLE_SCHEM), new Field("", "MAXIMUM_SCALE", FKTABLE_SCHEM, FKTABLE_SCHEM), new Field("", "SQL_DATA_TYPE", FKTABLE_CAT, DELETE_RULE), new Field("", "SQL_DATETIME_SUB", FKTABLE_CAT, DELETE_RULE), new Field("", "NUM_PREC_RADIX", FKTABLE_CAT, DELETE_RULE)};
        ArrayList tuples = new ArrayList();
        tuples.add(new ByteArrayRow(new byte[]{s2b("BIT"), Integer.toString(-7).getBytes(), s2b("1"), s2b(""), s2b(""), s2b(""), Integer.toString(1).getBytes(), s2b("true"), Integer.toString(PKCOLUMN_NAME).getBytes(), s2b("false"), s2b("false"), s2b("false"), s2b("BIT"), s2b("0"), s2b("0"), s2b("0"), s2b("0"), s2b("10")}));
        tuples.add(new ByteArrayRow(new byte[]{s2b("BOOL"), Integer.toString(-7).getBytes(), s2b("1"), s2b(""), s2b(""), s2b(""), Integer.toString(1).getBytes(), s2b("true"), Integer.toString(PKCOLUMN_NAME).getBytes(), s2b("false"), s2b("false"), s2b("false"), s2b("BOOL"), s2b("0"), s2b("0"), s2b("0"), s2b("0"), s2b("10")}));
        tuples.add(new ByteArrayRow(new byte[]{s2b("TINYINT"), Integer.toString(-6).getBytes(), s2b("3"), s2b(""), s2b(""), s2b("[(M)] [UNSIGNED] [ZEROFILL]"), Integer.toString(1).getBytes(), s2b("false"), Integer.toString(PKCOLUMN_NAME).getBytes(), s2b("true"), s2b("false"), s2b("true"), s2b("TINYINT"), s2b("0"), s2b("0"), s2b("0"), s2b("0"), s2b("10")}));
        tuples.add(new ByteArrayRow(new byte[]{s2b("BIGINT"), Integer.toString(-5).getBytes(), s2b("19"), s2b(""), s2b(""), s2b("[(M)] [UNSIGNED] [ZEROFILL]"), Integer.toString(1).getBytes(), s2b("false"), Integer.toString(PKCOLUMN_NAME).getBytes(), s2b("true"), s2b("false"), s2b("true"), s2b("BIGINT"), s2b("0"), s2b("0"), s2b("0"), s2b("0"), s2b("10")}));
        tuples.add(new ByteArrayRow(new byte[]{s2b("LONG VARBINARY"), Integer.toString(-4).getBytes(), s2b("16777215"), s2b("'"), s2b("'"), s2b(""), Integer.toString(1).getBytes(), s2b("true"), Integer.toString(PKCOLUMN_NAME).getBytes(), s2b("false"), s2b("false"), s2b("false"), s2b("LONG VARBINARY"), s2b("0"), s2b("0"), s2b("0"), s2b("0"), s2b("10")}));
        tuples.add(new ByteArrayRow(new byte[]{s2b("MEDIUMBLOB"), Integer.toString(-4).getBytes(), s2b("16777215"), s2b("'"), s2b("'"), s2b(""), Integer.toString(1).getBytes(), s2b("true"), Integer.toString(PKCOLUMN_NAME).getBytes(), s2b("false"), s2b("false"), s2b("false"), s2b("MEDIUMBLOB"), s2b("0"), s2b("0"), s2b("0"), s2b("0"), s2b("10")}));
        tuples.add(new ByteArrayRow(new byte[]{s2b("LONGBLOB"), Integer.toString(-4).getBytes(), Integer.toString(Integer.MAX_VALUE).getBytes(), s2b("'"), s2b("'"), s2b(""), Integer.toString(1).getBytes(), s2b("true"), Integer.toString(PKCOLUMN_NAME).getBytes(), s2b("false"), s2b("false"), s2b("false"), s2b("LONGBLOB"), s2b("0"), s2b("0"), s2b("0"), s2b("0"), s2b("10")}));
        tuples.add(new ByteArrayRow(new byte[]{s2b("BLOB"), Integer.toString(-4).getBytes(), s2b("65535"), s2b("'"), s2b("'"), s2b(""), Integer.toString(1).getBytes(), s2b("true"), Integer.toString(PKCOLUMN_NAME).getBytes(), s2b("false"), s2b("false"), s2b("false"), s2b("BLOB"), s2b("0"), s2b("0"), s2b("0"), s2b("0"), s2b("10")}));
        tuples.add(new ByteArrayRow(new byte[]{s2b("TINYBLOB"), Integer.toString(-4).getBytes(), s2b("255"), s2b("'"), s2b("'"), s2b(""), Integer.toString(1).getBytes(), s2b("true"), Integer.toString(PKCOLUMN_NAME).getBytes(), s2b("false"), s2b("false"), s2b("false"), s2b("TINYBLOB"), s2b("0"), s2b("0"), s2b("0"), s2b("0"), s2b("10")}));
        tuples.add(new ByteArrayRow(new byte[]{s2b("VARBINARY"), Integer.toString(-3).getBytes(), s2b("255"), s2b("'"), s2b("'"), s2b("(M)"), Integer.toString(1).getBytes(), s2b("true"), Integer.toString(PKCOLUMN_NAME).getBytes(), s2b("false"), s2b("false"), s2b("false"), s2b("VARBINARY"), s2b("0"), s2b("0"), s2b("0"), s2b("0"), s2b("10")}));
        tuples.add(new ByteArrayRow(new byte[]{s2b("BINARY"), Integer.toString(-2).getBytes(), s2b("255"), s2b("'"), s2b("'"), s2b("(M)"), Integer.toString(1).getBytes(), s2b("true"), Integer.toString(PKCOLUMN_NAME).getBytes(), s2b("false"), s2b("false"), s2b("false"), s2b("BINARY"), s2b("0"), s2b("0"), s2b("0"), s2b("0"), s2b("10")}));
        tuples.add(new ByteArrayRow(new byte[]{s2b("LONG VARCHAR"), Integer.toString(-1).getBytes(), s2b("16777215"), s2b("'"), s2b("'"), s2b(""), Integer.toString(1).getBytes(), s2b("false"), Integer.toString(PKCOLUMN_NAME).getBytes(), s2b("false"), s2b("false"), s2b("false"), s2b("LONG VARCHAR"), s2b("0"), s2b("0"), s2b("0"), s2b("0"), s2b("10")}));
        tuples.add(new ByteArrayRow(new byte[]{s2b("MEDIUMTEXT"), Integer.toString(-1).getBytes(), s2b("16777215"), s2b("'"), s2b("'"), s2b(""), Integer.toString(1).getBytes(), s2b("false"), Integer.toString(PKCOLUMN_NAME).getBytes(), s2b("false"), s2b("false"), s2b("false"), s2b("MEDIUMTEXT"), s2b("0"), s2b("0"), s2b("0"), s2b("0"), s2b("10")}));
        tuples.add(new ByteArrayRow(new byte[]{s2b("LONGTEXT"), Integer.toString(-1).getBytes(), Integer.toString(Integer.MAX_VALUE).getBytes(), s2b("'"), s2b("'"), s2b(""), Integer.toString(1).getBytes(), s2b("false"), Integer.toString(PKCOLUMN_NAME).getBytes(), s2b("false"), s2b("false"), s2b("false"), s2b("LONGTEXT"), s2b("0"), s2b("0"), s2b("0"), s2b("0"), s2b("10")}));
        tuples.add(new ByteArrayRow(new byte[]{s2b("TEXT"), Integer.toString(-1).getBytes(), s2b("65535"), s2b("'"), s2b("'"), s2b(""), Integer.toString(1).getBytes(), s2b("false"), Integer.toString(PKCOLUMN_NAME).getBytes(), s2b("false"), s2b("false"), s2b("false"), s2b("TEXT"), s2b("0"), s2b("0"), s2b("0"), s2b("0"), s2b("10")}));
        tuples.add(new ByteArrayRow(new byte[]{s2b("TINYTEXT"), Integer.toString(-1).getBytes(), s2b("255"), s2b("'"), s2b("'"), s2b(""), Integer.toString(1).getBytes(), s2b("false"), Integer.toString(PKCOLUMN_NAME).getBytes(), s2b("false"), s2b("false"), s2b("false"), s2b("TINYTEXT"), s2b("0"), s2b("0"), s2b("0"), s2b("0"), s2b("10")}));
        tuples.add(new ByteArrayRow(new byte[]{s2b("CHAR"), Integer.toString(1).getBytes(), s2b("255"), s2b("'"), s2b("'"), s2b("(M)"), Integer.toString(1).getBytes(), s2b("false"), Integer.toString(PKCOLUMN_NAME).getBytes(), s2b("false"), s2b("false"), s2b("false"), s2b("CHAR"), s2b("0"), s2b("0"), s2b("0"), s2b("0"), s2b("10")}));
        tuples.add(new ByteArrayRow(new byte[]{s2b("NUMERIC"), Integer.toString(PKTABLE_NAME).getBytes(), s2b("17"), s2b(""), s2b(""), s2b("[(M[,D])] [ZEROFILL]"), Integer.toString(1).getBytes(), s2b("false"), Integer.toString(PKCOLUMN_NAME).getBytes(), s2b("false"), s2b("false"), s2b("true"), s2b("NUMERIC"), s2b("-308"), s2b("308"), s2b("0"), s2b("0"), s2b("10")}));
        tuples.add(new ByteArrayRow(new byte[]{s2b("DECIMAL"), Integer.toString(PKCOLUMN_NAME).getBytes(), s2b("17"), s2b(""), s2b(""), s2b("[(M[,D])] [ZEROFILL]"), Integer.toString(1).getBytes(), s2b("false"), Integer.toString(PKCOLUMN_NAME).getBytes(), s2b("false"), s2b("false"), s2b("true"), s2b("DECIMAL"), s2b("-308"), s2b("308"), s2b("0"), s2b("0"), s2b("10")}));
        tuples.add(new ByteArrayRow(new byte[]{s2b("INTEGER"), Integer.toString(FKTABLE_CAT).getBytes(), s2b("10"), s2b(""), s2b(""), s2b("[(M)] [UNSIGNED] [ZEROFILL]"), Integer.toString(1).getBytes(), s2b("false"), Integer.toString(PKCOLUMN_NAME).getBytes(), s2b("true"), s2b("false"), s2b("true"), s2b("INTEGER"), s2b("0"), s2b("0"), s2b("0"), s2b("0"), s2b("10")}));
        tuples.add(new ByteArrayRow(new byte[]{s2b("INT"), Integer.toString(FKTABLE_CAT).getBytes(), s2b("10"), s2b(""), s2b(""), s2b("[(M)] [UNSIGNED] [ZEROFILL]"), Integer.toString(1).getBytes(), s2b("false"), Integer.toString(PKCOLUMN_NAME).getBytes(), s2b("true"), s2b("false"), s2b("true"), s2b("INT"), s2b("0"), s2b("0"), s2b("0"), s2b("0"), s2b("10")}));
        tuples.add(new ByteArrayRow(new byte[]{s2b("MEDIUMINT"), Integer.toString(FKTABLE_CAT).getBytes(), s2b("7"), s2b(""), s2b(""), s2b("[(M)] [UNSIGNED] [ZEROFILL]"), Integer.toString(1).getBytes(), s2b("false"), Integer.toString(PKCOLUMN_NAME).getBytes(), s2b("true"), s2b("false"), s2b("true"), s2b("MEDIUMINT"), s2b("0"), s2b("0"), s2b("0"), s2b("0"), s2b("10")}));
        tuples.add(new ByteArrayRow(new byte[]{s2b("SMALLINT"), Integer.toString(FKTABLE_SCHEM).getBytes(), s2b("5"), s2b(""), s2b(""), s2b("[(M)] [UNSIGNED] [ZEROFILL]"), Integer.toString(1).getBytes(), s2b("false"), Integer.toString(PKCOLUMN_NAME).getBytes(), s2b("true"), s2b("false"), s2b("true"), s2b("SMALLINT"), s2b("0"), s2b("0"), s2b("0"), s2b("0"), s2b("10")}));
        tuples.add(new ByteArrayRow(new byte[]{s2b("FLOAT"), Integer.toString(FKCOLUMN_NAME).getBytes(), s2b("10"), s2b(""), s2b(""), s2b("[(M,D)] [ZEROFILL]"), Integer.toString(1).getBytes(), s2b("false"), Integer.toString(PKCOLUMN_NAME).getBytes(), s2b("false"), s2b("false"), s2b("true"), s2b("FLOAT"), s2b("-38"), s2b("38"), s2b("0"), s2b("0"), s2b("10")}));
        tuples.add(new ByteArrayRow(new byte[]{s2b("DOUBLE"), Integer.toString(KEY_SEQ).getBytes(), s2b("17"), s2b(""), s2b(""), s2b("[(M,D)] [ZEROFILL]"), Integer.toString(1).getBytes(), s2b("false"), Integer.toString(PKCOLUMN_NAME).getBytes(), s2b("false"), s2b("false"), s2b("true"), s2b("DOUBLE"), s2b("-308"), s2b("308"), s2b("0"), s2b("0"), s2b("10")}));
        tuples.add(new ByteArrayRow(new byte[]{s2b("DOUBLE PRECISION"), Integer.toString(KEY_SEQ).getBytes(), s2b("17"), s2b(""), s2b(""), s2b("[(M,D)] [ZEROFILL]"), Integer.toString(1).getBytes(), s2b("false"), Integer.toString(PKCOLUMN_NAME).getBytes(), s2b("false"), s2b("false"), s2b("true"), s2b("DOUBLE PRECISION"), s2b("-308"), s2b("308"), s2b("0"), s2b("0"), s2b("10")}));
        tuples.add(new ByteArrayRow(new byte[]{s2b("REAL"), Integer.toString(KEY_SEQ).getBytes(), s2b("17"), s2b(""), s2b(""), s2b("[(M,D)] [ZEROFILL]"), Integer.toString(1).getBytes(), s2b("false"), Integer.toString(PKCOLUMN_NAME).getBytes(), s2b("false"), s2b("false"), s2b("true"), s2b("REAL"), s2b("-308"), s2b("308"), s2b("0"), s2b("0"), s2b("10")}));
        tuples.add(new ByteArrayRow(new byte[]{s2b("VARCHAR"), Integer.toString(PK_NAME).getBytes(), s2b("255"), s2b("'"), s2b("'"), s2b("(M)"), Integer.toString(1).getBytes(), s2b("false"), Integer.toString(PKCOLUMN_NAME).getBytes(), s2b("false"), s2b("false"), s2b("false"), s2b("VARCHAR"), s2b("0"), s2b("0"), s2b("0"), s2b("0"), s2b("10")}));
        tuples.add(new ByteArrayRow(new byte[]{s2b("ENUM"), Integer.toString(PK_NAME).getBytes(), s2b("65535"), s2b("'"), s2b("'"), s2b(""), Integer.toString(1).getBytes(), s2b("false"), Integer.toString(PKCOLUMN_NAME).getBytes(), s2b("false"), s2b("false"), s2b("false"), s2b("ENUM"), s2b("0"), s2b("0"), s2b("0"), s2b("0"), s2b("10")}));
        tuples.add(new ByteArrayRow(new byte[]{s2b("SET"), Integer.toString(PK_NAME).getBytes(), s2b("64"), s2b("'"), s2b("'"), s2b(""), Integer.toString(1).getBytes(), s2b("false"), Integer.toString(PKCOLUMN_NAME).getBytes(), s2b("false"), s2b("false"), s2b("false"), s2b("SET"), s2b("0"), s2b("0"), s2b("0"), s2b("0"), s2b("10")}));
        tuples.add(new ByteArrayRow(new byte[]{s2b("DATE"), Integer.toString(91).getBytes(), s2b("0"), s2b("'"), s2b("'"), s2b(""), Integer.toString(1).getBytes(), s2b("false"), Integer.toString(PKCOLUMN_NAME).getBytes(), s2b("false"), s2b("false"), s2b("false"), s2b("DATE"), s2b("0"), s2b("0"), s2b("0"), s2b("0"), s2b("10")}));
        tuples.add(new ByteArrayRow(new byte[]{s2b("TIME"), Integer.toString(92).getBytes(), s2b("0"), s2b("'"), s2b("'"), s2b(""), Integer.toString(1).getBytes(), s2b("false"), Integer.toString(PKCOLUMN_NAME).getBytes(), s2b("false"), s2b("false"), s2b("false"), s2b("TIME"), s2b("0"), s2b("0"), s2b("0"), s2b("0"), s2b("10")}));
        tuples.add(new ByteArrayRow(new byte[]{s2b("DATETIME"), Integer.toString(93).getBytes(), s2b("0"), s2b("'"), s2b("'"), s2b(""), Integer.toString(1).getBytes(), s2b("false"), Integer.toString(PKCOLUMN_NAME).getBytes(), s2b("false"), s2b("false"), s2b("false"), s2b("DATETIME"), s2b("0"), s2b("0"), s2b("0"), s2b("0"), s2b("10")}));
        tuples.add(new ByteArrayRow(new byte[]{s2b("TIMESTAMP"), Integer.toString(93).getBytes(), s2b("0"), s2b("'"), s2b("'"), s2b("[(M)]"), Integer.toString(1).getBytes(), s2b("false"), Integer.toString(PKCOLUMN_NAME).getBytes(), s2b("false"), s2b("false"), s2b("false"), s2b("TIMESTAMP"), s2b("0"), s2b("0"), s2b("0"), s2b("0"), s2b("10")}));
        return buildResultSet(fields, tuples);
    }

    @Override // java.sql.DatabaseMetaData
    public ResultSet getUDTs(String catalog, String schemaPattern, String typeNamePattern, int[] types) throws SQLException {
        Field[] fields = {new Field("", "TYPE_CAT", PK_NAME, 32), new Field("", "TYPE_SCHEM", PK_NAME, 32), new Field("", "TYPE_NAME", PK_NAME, 32), new Field("", "CLASS_NAME", PK_NAME, 32), new Field("", "DATA_TYPE", PK_NAME, 32), new Field("", "REMARKS", PK_NAME, 32)};
        ArrayList tuples = new ArrayList();
        return buildResultSet(fields, tuples);
    }

    @Override // java.sql.DatabaseMetaData
    public String getURL() throws SQLException {
        return this.conn.getURL();
    }

    /*  JADX ERROR: JadxRuntimeException in pass: BlockProcessor
        jadx.core.utils.exceptions.JadxRuntimeException: Unreachable block: B:13:0x0068
        	at jadx.core.dex.visitors.blocks.BlockProcessor.checkForUnreachableBlocks(BlockProcessor.java:88)
        	at jadx.core.dex.visitors.blocks.BlockProcessor.processBlocksTree(BlockProcessor.java:52)
        	at jadx.core.dex.visitors.blocks.BlockProcessor.visit(BlockProcessor.java:44)
        */
    @Override // java.sql.DatabaseMetaData
    public java.lang.String getUserName() throws java.sql.SQLException {
        /*
            r3 = this;
            r0 = r3
            com.mysql.jdbc.ConnectionImpl r0 = r0.conn
            boolean r0 = r0.getUseHostsInPrivileges()
            if (r0 == 0) goto L73
            r0 = 0
            r4 = r0
            r0 = 0
            r5 = r0
            r0 = r3
            com.mysql.jdbc.ConnectionImpl r0 = r0.conn     // Catch: java.lang.Throwable -> L3b
            java.sql.Statement r0 = r0.createStatement()     // Catch: java.lang.Throwable -> L3b
            r4 = r0
            r0 = r4
            r1 = 0
            r0.setEscapeProcessing(r1)     // Catch: java.lang.Throwable -> L3b
            r0 = r4
            java.lang.String r1 = "SELECT USER()"
            java.sql.ResultSet r0 = r0.executeQuery(r1)     // Catch: java.lang.Throwable -> L3b
            r5 = r0
            r0 = r5
            boolean r0 = r0.next()     // Catch: java.lang.Throwable -> L3b
            r0 = r5
            r1 = 1
            java.lang.String r0 = r0.getString(r1)     // Catch: java.lang.Throwable -> L3b
            r6 = r0
            r0 = jsr -> L43
        L39:
            r1 = r6
            return r1
        L3b:
            r7 = move-exception
            r0 = jsr -> L43
        L40:
            r1 = r7
            throw r1
        L43:
            r8 = r0
            r0 = r5
            if (r0 == 0) goto L5b
            r0 = r5
            r0.close()     // Catch: java.lang.Exception -> L52
            goto L59
        L52:
            r9 = move-exception
            r0 = r9
            com.mysql.jdbc.AssertionFailedException.shouldNotHappen(r0)
        L59:
            r0 = 0
            r5 = r0
        L5b:
            r0 = r4
            if (r0 == 0) goto L71
            r0 = r4
            r0.close()     // Catch: java.lang.Exception -> L68
            goto L6f
        L68:
            r9 = move-exception
            r0 = r9
            com.mysql.jdbc.AssertionFailedException.shouldNotHappen(r0)
        L6f:
            r0 = 0
            r4 = r0
        L71:
            ret r8
        L73:
            r0 = r3
            com.mysql.jdbc.ConnectionImpl r0 = r0.conn
            java.lang.String r0 = r0.getUser()
            return r0
        */
        throw new UnsupportedOperationException("Method not decompiled: com.mysql.jdbc.DatabaseMetaData.getUserName():java.lang.String");
    }

    @Override // java.sql.DatabaseMetaData
    public ResultSet getVersionColumns(String catalog, String schema, String table) throws SQLException {
        Field[] fields = {new Field("", "SCOPE", FKTABLE_SCHEM, FKTABLE_SCHEM), new Field("", "COLUMN_NAME", 1, 32), new Field("", "DATA_TYPE", FKTABLE_SCHEM, FKTABLE_SCHEM), new Field("", "TYPE_NAME", 1, 16), new Field("", "COLUMN_SIZE", 1, 16), new Field("", "BUFFER_LENGTH", 1, 16), new Field("", "DECIMAL_DIGITS", 1, 16), new Field("", "PSEUDO_COLUMN", FKTABLE_SCHEM, FKTABLE_SCHEM)};
        return buildResultSet(fields, new ArrayList());
    }

    @Override // java.sql.DatabaseMetaData
    public boolean insertsAreDetected(int type) throws SQLException {
        return false;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean isCatalogAtStart() throws SQLException {
        return true;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean isReadOnly() throws SQLException {
        return false;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean locatorsUpdateCopy() throws SQLException {
        return !this.conn.getEmulateLocators();
    }

    @Override // java.sql.DatabaseMetaData
    public boolean nullPlusNonNullIsNull() throws SQLException {
        return true;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean nullsAreSortedAtEnd() throws SQLException {
        return false;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean nullsAreSortedAtStart() throws SQLException {
        return this.conn.versionMeetsMinimum(FKTABLE_CAT, 0, PKTABLE_NAME) && !this.conn.versionMeetsMinimum(FKTABLE_CAT, 0, FK_NAME);
    }

    @Override // java.sql.DatabaseMetaData
    public boolean nullsAreSortedHigh() throws SQLException {
        return false;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean nullsAreSortedLow() throws SQLException {
        return !nullsAreSortedHigh();
    }

    @Override // java.sql.DatabaseMetaData
    public boolean othersDeletesAreVisible(int type) throws SQLException {
        return false;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean othersInsertsAreVisible(int type) throws SQLException {
        return false;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean othersUpdatesAreVisible(int type) throws SQLException {
        return false;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean ownDeletesAreVisible(int type) throws SQLException {
        return false;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean ownInsertsAreVisible(int type) throws SQLException {
        return false;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean ownUpdatesAreVisible(int type) throws SQLException {
        return false;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public LocalAndReferencedColumns parseTableStatusIntoLocalAndReferencedColumns(String keysComment) throws SQLException {
        char quoteChar = this.quotedId.length() == 0 ? (char) 0 : this.quotedId.charAt(0);
        int indexOfOpenParenLocalColumns = StringUtils.indexOfIgnoreCaseRespectQuotes(0, keysComment, "(", quoteChar, true);
        if (indexOfOpenParenLocalColumns == -1) {
            throw SQLError.createSQLException("Error parsing foreign keys definition, couldn't find start of local columns list.", SQLError.SQL_STATE_GENERAL_ERROR);
        }
        String constraintName = removeQuotedId(keysComment.substring(0, indexOfOpenParenLocalColumns).trim());
        String keysCommentTrimmed = keysComment.substring(indexOfOpenParenLocalColumns, keysComment.length()).trim();
        int indexOfCloseParenLocalColumns = StringUtils.indexOfIgnoreCaseRespectQuotes(0, keysCommentTrimmed, ")", quoteChar, true);
        if (indexOfCloseParenLocalColumns == -1) {
            throw SQLError.createSQLException("Error parsing foreign keys definition, couldn't find end of local columns list.", SQLError.SQL_STATE_GENERAL_ERROR);
        }
        String localColumnNamesString = keysCommentTrimmed.substring(1, indexOfCloseParenLocalColumns);
        int indexOfRefer = StringUtils.indexOfIgnoreCaseRespectQuotes(0, keysCommentTrimmed, "REFER ", this.quotedId.charAt(0), true);
        if (indexOfRefer == -1) {
            throw SQLError.createSQLException("Error parsing foreign keys definition, couldn't find start of referenced tables list.", SQLError.SQL_STATE_GENERAL_ERROR);
        }
        int indexOfOpenParenReferCol = StringUtils.indexOfIgnoreCaseRespectQuotes(indexOfRefer, keysCommentTrimmed, "(", quoteChar, false);
        if (indexOfOpenParenReferCol == -1) {
            throw SQLError.createSQLException("Error parsing foreign keys definition, couldn't find start of referenced columns list.", SQLError.SQL_STATE_GENERAL_ERROR);
        }
        String referCatalogTableString = keysCommentTrimmed.substring(indexOfRefer + "REFER ".length(), indexOfOpenParenReferCol);
        int indexOfSlash = StringUtils.indexOfIgnoreCaseRespectQuotes(0, referCatalogTableString, "/", this.quotedId.charAt(0), false);
        if (indexOfSlash == -1) {
            throw SQLError.createSQLException("Error parsing foreign keys definition, couldn't find name of referenced catalog.", SQLError.SQL_STATE_GENERAL_ERROR);
        }
        String referCatalog = removeQuotedId(referCatalogTableString.substring(0, indexOfSlash));
        String referTable = removeQuotedId(referCatalogTableString.substring(indexOfSlash + 1).trim());
        int indexOfCloseParenRefer = StringUtils.indexOfIgnoreCaseRespectQuotes(indexOfOpenParenReferCol, keysCommentTrimmed, ")", quoteChar, true);
        if (indexOfCloseParenRefer == -1) {
            throw SQLError.createSQLException("Error parsing foreign keys definition, couldn't find end of referenced columns list.", SQLError.SQL_STATE_GENERAL_ERROR);
        }
        String referColumnNamesString = keysCommentTrimmed.substring(indexOfOpenParenReferCol + 1, indexOfCloseParenRefer);
        List referColumnsList = StringUtils.split(referColumnNamesString, ",", this.quotedId, this.quotedId, false);
        List localColumnsList = StringUtils.split(localColumnNamesString, ",", this.quotedId, this.quotedId, false);
        return new LocalAndReferencedColumns(this, localColumnsList, referColumnsList, constraintName, referCatalog, referTable);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public String removeQuotedId(String s) {
        if (s == null) {
            return null;
        }
        if (this.quotedId.equals("")) {
            return s;
        }
        String s2 = s.trim();
        int frontOffset = 0;
        int backOffset = s2.length();
        int quoteLength = this.quotedId.length();
        if (s2.startsWith(this.quotedId)) {
            frontOffset = quoteLength;
        }
        if (s2.endsWith(this.quotedId)) {
            backOffset -= quoteLength;
        }
        return s2.substring(frontOffset, backOffset);
    }

    protected byte[] s2b(String s) throws SQLException {
        return StringUtils.s2b(s, this.conn);
    }

    @Override // java.sql.DatabaseMetaData
    public boolean storesLowerCaseIdentifiers() throws SQLException {
        return this.conn.lowerCaseTableNames();
    }

    @Override // java.sql.DatabaseMetaData
    public boolean storesLowerCaseQuotedIdentifiers() throws SQLException {
        return this.conn.lowerCaseTableNames();
    }

    @Override // java.sql.DatabaseMetaData
    public boolean storesMixedCaseIdentifiers() throws SQLException {
        return !this.conn.lowerCaseTableNames();
    }

    @Override // java.sql.DatabaseMetaData
    public boolean storesMixedCaseQuotedIdentifiers() throws SQLException {
        return !this.conn.lowerCaseTableNames();
    }

    @Override // java.sql.DatabaseMetaData
    public boolean storesUpperCaseIdentifiers() throws SQLException {
        return false;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean storesUpperCaseQuotedIdentifiers() throws SQLException {
        return true;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsAlterTableWithAddColumn() throws SQLException {
        return true;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsAlterTableWithDropColumn() throws SQLException {
        return true;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsANSI92EntryLevelSQL() throws SQLException {
        return true;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsANSI92FullSQL() throws SQLException {
        return false;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsANSI92IntermediateSQL() throws SQLException {
        return false;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsBatchUpdates() throws SQLException {
        return true;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsCatalogsInDataManipulation() throws SQLException {
        return this.conn.versionMeetsMinimum(PKCOLUMN_NAME, 22, 0);
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsCatalogsInIndexDefinitions() throws SQLException {
        return this.conn.versionMeetsMinimum(PKCOLUMN_NAME, 22, 0);
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsCatalogsInPrivilegeDefinitions() throws SQLException {
        return this.conn.versionMeetsMinimum(PKCOLUMN_NAME, 22, 0);
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsCatalogsInProcedureCalls() throws SQLException {
        return this.conn.versionMeetsMinimum(PKCOLUMN_NAME, 22, 0);
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsCatalogsInTableDefinitions() throws SQLException {
        return this.conn.versionMeetsMinimum(PKCOLUMN_NAME, 22, 0);
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsColumnAliasing() throws SQLException {
        return true;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsConvert() throws SQLException {
        return false;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsConvert(int fromType, int toType) throws SQLException {
        switch (fromType) {
            case -7:
                return false;
            case -6:
            case -5:
            case PKTABLE_NAME /* 2 */:
            case PKCOLUMN_NAME /* 3 */:
            case FKTABLE_CAT /* 4 */:
            case FKTABLE_SCHEM /* 5 */:
            case FKTABLE_NAME /* 6 */:
            case FKCOLUMN_NAME /* 7 */:
            case KEY_SEQ /* 8 */:
                switch (toType) {
                    case -6:
                    case -5:
                    case -4:
                    case -3:
                    case -2:
                    case -1:
                    case 1:
                    case PKTABLE_NAME /* 2 */:
                    case PKCOLUMN_NAME /* 3 */:
                    case FKTABLE_CAT /* 4 */:
                    case FKTABLE_SCHEM /* 5 */:
                    case FKTABLE_NAME /* 6 */:
                    case FKCOLUMN_NAME /* 7 */:
                    case KEY_SEQ /* 8 */:
                    case PK_NAME /* 12 */:
                        return true;
                    case 0:
                    case UPDATE_RULE /* 9 */:
                    case DELETE_RULE /* 10 */:
                    case FK_NAME /* 11 */:
                    default:
                        return false;
                }
            case -4:
            case -3:
            case -2:
            case -1:
            case 1:
            case PK_NAME /* 12 */:
                switch (toType) {
                    case -6:
                    case -5:
                    case -4:
                    case -3:
                    case -2:
                    case -1:
                    case 1:
                    case PKTABLE_NAME /* 2 */:
                    case PKCOLUMN_NAME /* 3 */:
                    case FKTABLE_CAT /* 4 */:
                    case FKTABLE_SCHEM /* 5 */:
                    case FKTABLE_NAME /* 6 */:
                    case FKCOLUMN_NAME /* 7 */:
                    case KEY_SEQ /* 8 */:
                    case PK_NAME /* 12 */:
                    case 91:
                    case 92:
                    case 93:
                    case MysqlErrorNumbers.ER_INVALID_GROUP_FUNC_USE /* 1111 */:
                        return true;
                    default:
                        return false;
                }
            case 0:
                return false;
            case 91:
                switch (toType) {
                    case -4:
                    case -3:
                    case -2:
                    case -1:
                    case 1:
                    case PK_NAME /* 12 */:
                        return true;
                    case 0:
                    case PKTABLE_NAME /* 2 */:
                    case PKCOLUMN_NAME /* 3 */:
                    case FKTABLE_CAT /* 4 */:
                    case FKTABLE_SCHEM /* 5 */:
                    case FKTABLE_NAME /* 6 */:
                    case FKCOLUMN_NAME /* 7 */:
                    case KEY_SEQ /* 8 */:
                    case UPDATE_RULE /* 9 */:
                    case DELETE_RULE /* 10 */:
                    case FK_NAME /* 11 */:
                    default:
                        return false;
                }
            case 92:
                switch (toType) {
                    case -4:
                    case -3:
                    case -2:
                    case -1:
                    case 1:
                    case PK_NAME /* 12 */:
                        return true;
                    case 0:
                    case PKTABLE_NAME /* 2 */:
                    case PKCOLUMN_NAME /* 3 */:
                    case FKTABLE_CAT /* 4 */:
                    case FKTABLE_SCHEM /* 5 */:
                    case FKTABLE_NAME /* 6 */:
                    case FKCOLUMN_NAME /* 7 */:
                    case KEY_SEQ /* 8 */:
                    case UPDATE_RULE /* 9 */:
                    case DELETE_RULE /* 10 */:
                    case FK_NAME /* 11 */:
                    default:
                        return false;
                }
            case 93:
                switch (toType) {
                    case -4:
                    case -3:
                    case -2:
                    case -1:
                    case 1:
                    case PK_NAME /* 12 */:
                    case 91:
                    case 92:
                        return true;
                    default:
                        return false;
                }
            case MysqlErrorNumbers.ER_INVALID_GROUP_FUNC_USE /* 1111 */:
                switch (toType) {
                    case -4:
                    case -3:
                    case -2:
                    case -1:
                    case 1:
                    case PK_NAME /* 12 */:
                        return true;
                    case 0:
                    case PKTABLE_NAME /* 2 */:
                    case PKCOLUMN_NAME /* 3 */:
                    case FKTABLE_CAT /* 4 */:
                    case FKTABLE_SCHEM /* 5 */:
                    case FKTABLE_NAME /* 6 */:
                    case FKCOLUMN_NAME /* 7 */:
                    case KEY_SEQ /* 8 */:
                    case UPDATE_RULE /* 9 */:
                    case DELETE_RULE /* 10 */:
                    case FK_NAME /* 11 */:
                    default:
                        return false;
                }
            default:
                return false;
        }
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsCoreSQLGrammar() throws SQLException {
        return true;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsCorrelatedSubqueries() throws SQLException {
        return this.conn.versionMeetsMinimum(FKTABLE_CAT, 1, 0);
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsDataDefinitionAndDataManipulationTransactions() throws SQLException {
        return false;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsDataManipulationTransactionsOnly() throws SQLException {
        return false;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsDifferentTableCorrelationNames() throws SQLException {
        return true;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsExpressionsInOrderBy() throws SQLException {
        return true;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsExtendedSQLGrammar() throws SQLException {
        return false;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsFullOuterJoins() throws SQLException {
        return false;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsGetGeneratedKeys() {
        return true;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsGroupBy() throws SQLException {
        return true;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsGroupByBeyondSelect() throws SQLException {
        return true;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsGroupByUnrelated() throws SQLException {
        return true;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsIntegrityEnhancementFacility() throws SQLException {
        if (!this.conn.getOverrideSupportsIntegrityEnhancementFacility()) {
            return false;
        }
        return true;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsLikeEscapeClause() throws SQLException {
        return true;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsLimitedOuterJoins() throws SQLException {
        return true;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsMinimumSQLGrammar() throws SQLException {
        return true;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsMixedCaseIdentifiers() throws SQLException {
        return !this.conn.lowerCaseTableNames();
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsMixedCaseQuotedIdentifiers() throws SQLException {
        return !this.conn.lowerCaseTableNames();
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsMultipleOpenResults() throws SQLException {
        return true;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsMultipleResultSets() throws SQLException {
        return false;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsMultipleTransactions() throws SQLException {
        return true;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsNamedParameters() throws SQLException {
        return false;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsNonNullableColumns() throws SQLException {
        return true;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsOpenCursorsAcrossCommit() throws SQLException {
        return false;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsOpenCursorsAcrossRollback() throws SQLException {
        return false;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsOpenStatementsAcrossCommit() throws SQLException {
        return false;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsOpenStatementsAcrossRollback() throws SQLException {
        return false;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsOrderByUnrelated() throws SQLException {
        return false;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsOuterJoins() throws SQLException {
        return true;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsPositionedDelete() throws SQLException {
        return false;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsPositionedUpdate() throws SQLException {
        return false;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsResultSetConcurrency(int type, int concurrency) throws SQLException {
        switch (type) {
            case MysqlErrorNumbers.ER_YES /* 1003 */:
                if (concurrency == 1007 || concurrency == 1008) {
                    return true;
                }
                throw SQLError.createSQLException("Illegal arguments to supportsResultSetConcurrency()", SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
            case MysqlErrorNumbers.ER_CANT_CREATE_FILE /* 1004 */:
                if (concurrency == 1007 || concurrency == 1008) {
                    return true;
                }
                throw SQLError.createSQLException("Illegal arguments to supportsResultSetConcurrency()", SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
            case MysqlErrorNumbers.ER_CANT_CREATE_TABLE /* 1005 */:
                return false;
            default:
                throw SQLError.createSQLException("Illegal arguments to supportsResultSetConcurrency()", SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
        }
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsResultSetHoldability(int holdability) throws SQLException {
        return holdability == 1;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsResultSetType(int type) throws SQLException {
        return type == 1004;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsSavepoints() throws SQLException {
        return this.conn.versionMeetsMinimum(FKTABLE_CAT, 0, 14) || this.conn.versionMeetsMinimum(FKTABLE_CAT, 1, 1);
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsSchemasInDataManipulation() throws SQLException {
        return false;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsSchemasInIndexDefinitions() throws SQLException {
        return false;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsSchemasInPrivilegeDefinitions() throws SQLException {
        return false;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsSchemasInProcedureCalls() throws SQLException {
        return false;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsSchemasInTableDefinitions() throws SQLException {
        return false;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsSelectForUpdate() throws SQLException {
        return this.conn.versionMeetsMinimum(FKTABLE_CAT, 0, 0);
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsStatementPooling() throws SQLException {
        return false;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsStoredProcedures() throws SQLException {
        return this.conn.versionMeetsMinimum(FKTABLE_SCHEM, 0, 0);
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsSubqueriesInComparisons() throws SQLException {
        return this.conn.versionMeetsMinimum(FKTABLE_CAT, 1, 0);
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsSubqueriesInExists() throws SQLException {
        return this.conn.versionMeetsMinimum(FKTABLE_CAT, 1, 0);
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsSubqueriesInIns() throws SQLException {
        return this.conn.versionMeetsMinimum(FKTABLE_CAT, 1, 0);
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsSubqueriesInQuantifieds() throws SQLException {
        return this.conn.versionMeetsMinimum(FKTABLE_CAT, 1, 0);
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsTableCorrelationNames() throws SQLException {
        return true;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsTransactionIsolationLevel(int level) throws SQLException {
        if (this.conn.supportsIsolationLevel()) {
            switch (level) {
                case 1:
                case PKTABLE_NAME /* 2 */:
                case FKTABLE_CAT /* 4 */:
                case KEY_SEQ /* 8 */:
                    return true;
                case PKCOLUMN_NAME /* 3 */:
                case FKTABLE_SCHEM /* 5 */:
                case FKTABLE_NAME /* 6 */:
                case FKCOLUMN_NAME /* 7 */:
                default:
                    return false;
            }
        }
        return false;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsTransactions() throws SQLException {
        return this.conn.supportsTransactions();
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsUnion() throws SQLException {
        return this.conn.versionMeetsMinimum(FKTABLE_CAT, 0, 0);
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsUnionAll() throws SQLException {
        return this.conn.versionMeetsMinimum(FKTABLE_CAT, 0, 0);
    }

    @Override // java.sql.DatabaseMetaData
    public boolean updatesAreDetected(int type) throws SQLException {
        return false;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean usesLocalFilePerTable() throws SQLException {
        return false;
    }

    @Override // java.sql.DatabaseMetaData
    public boolean usesLocalFiles() throws SQLException {
        return false;
    }

    @Override // java.sql.DatabaseMetaData
    public ResultSet getFunctionColumns(String catalog, String schemaPattern, String functionNamePattern, String columnNamePattern) throws SQLException {
        Field[] fields = {new Field("", "FUNCTION_CAT", PK_NAME, 0), new Field("", "FUNCTION_SCHEM", PK_NAME, 0), new Field("", "FUNCTION_NAME", PK_NAME, 0), new Field("", "COLUMN_NAME", PK_NAME, 0), new Field("", "COLUMN_TYPE", PK_NAME, 0), new Field("", "DATA_TYPE", FKTABLE_SCHEM, 0), new Field("", "TYPE_NAME", PK_NAME, 0), new Field("", "PRECISION", FKTABLE_CAT, 0), new Field("", "LENGTH", FKTABLE_CAT, 0), new Field("", "SCALE", FKTABLE_SCHEM, 0), new Field("", "RADIX", FKTABLE_SCHEM, 0), new Field("", "NULLABLE", FKTABLE_SCHEM, 0), new Field("", "REMARKS", PK_NAME, 0), new Field("", "CHAR_OCTET_LENGTH", FKTABLE_CAT, 0), new Field("", "ORDINAL_POSITION", FKTABLE_CAT, 0), new Field("", "IS_NULLABLE", PK_NAME, PKCOLUMN_NAME), new Field("", "SPECIFIC_NAME", PK_NAME, 0)};
        return getProcedureOrFunctionColumns(fields, catalog, schemaPattern, functionNamePattern, columnNamePattern, false, true);
    }

    public boolean providesQueryObjectGenerator() throws SQLException {
        return false;
    }

    @Override // java.sql.DatabaseMetaData
    public ResultSet getSchemas(String catalog, String schemaPattern) throws SQLException {
        Field[] fields = {new Field("", "TABLE_SCHEM", PK_NAME, 255), new Field("", "TABLE_CATALOG", PK_NAME, 255)};
        return buildResultSet(fields, new ArrayList());
    }

    @Override // java.sql.DatabaseMetaData
    public boolean supportsStoredFunctionsUsingCallSyntax() throws SQLException {
        return true;
    }
}
